List of S&P 500 companies - Wikipedia

# List of S&P 500 companies

From Wikipedia, the free encyclopedia

The S&P 500 stock market index, maintained by S&P Dow Jones Indices, comprises 505 common stocks issued by 500 mid and large-cap companies and traded on American stock exchanges, and covers about 75 percent of the American equity market by capitalization. The index is weighted by free-float market capitalization, so more valuable companies account for relatively more of the index. The index constituents and the constituent weights are updated and checked on regularly using rules published by S&P Dow Jones Indices. Although the index is called the S&P "500", the index contains 505 stocks because it includes two share classes of stock from 5 of its component companies.[1][2] The index constituents listed below were current as of November 5, 2016.

## S&P 500 Component Stocks[edit]

Ticker symbol | Security | SEC filings | GICS Sector | GICS Sub Industry | Address of Headquarters | Date first added | CIK
--- | --- | --- | --- | --- | --- | --- | ---
MMM | 3M Company | reports | Industrials | Industrial Conglomerates | St. Paul, Minnesota |  | 0000066740
ABT | Abbott Laboratories | reports | Health Care | Health Care Equipment | North Chicago, Illinois | 1964-03-31 | 0000001800
ABBV | AbbVie | reports | Health Care | Pharmaceuticals | North Chicago, Illinois | 2012-12-31 | 0001551152
ACN | Accenture plc | reports | Information Technology | IT Consulting & Other Services | Dublin, Ireland | 2011-07-06 | 0001467373
ATVI | Activision Blizzard | reports | Information Technology | Home Entertainment Software | Santa Monica, California | 2015-08-31 | 0000718877
AYI | Acuity Brands Inc | reports | Industrials | Electrical Components & Equipment | Atlanta, Georgia | 2016-05-03 | 0001144215
ADBE | Adobe Systems Inc | reports | Information Technology | Application Software | San Jose, California |  | 0000796343
AAP | Advance Auto Parts | reports | Consumer Discretionary | Automotive Retail | Roanoke, Virginia | 2015-07-09 | 0001158449
AES | AES Corp | reports | Utilities | Independent Power Producers & Energy Traders | Arlington, Virginia |  | 0000874761
AET | Aetna Inc | reports | Health Care | Managed Health Care | Hartford, Connecticut | 1976-06-30 | 0001122304
AFL | AFLAC Inc | reports | Financials | Life & Health Insurance | Columbus, Georgia |  | 0000004977
AMG | Affiliated Managers Group Inc | reports | Financials | Asset Management & Custody Banks | Beverly, Massachusetts | 2014-07-01 | 0001004434
A | Agilent Technologies Inc | reports | Health Care | Health Care Equipment | Santa Clara, California |  | 0001090872
APD | Air Products & Chemicals Inc | reports | Materials | Industrial Gases | Allentown, Pennsylvania | 1985-04-30 | 0000002969
AKAM | Akamai Technologies Inc | reports | Information Technology | Internet Software & Services | Cambridge, Massachusetts | 2007-07-12 | 0001086222
ALK | Alaska Air Group Inc | reports | Industrials | Airlines | Seattle, Washington | 2016-05-13 | 0000766421
ALB | Albemarle Corp | reports | Materials | Specialty Chemicals | Baton Rouge, Louisiana | 2016-07-01 | 0000915913
AGN | Allergan plc | reports | Health Care | Pharmaceuticals | Dublin, Ireland |  | 0000884629
LNT | Alliant Energy Corp | reports | Utilities | Electric Utilities | Madison, Wisconsin | 2016-07-01 | 0000352541
ALXN | Alexion Pharmaceuticals | reports | Health Care | Biotechnology | Cheshire, Connecticut | 2012-05-25 | 0000899866
ALLE | Allegion | reports | Industrials | Building Products | Dublin, Ireland | 2013-12-02 | 0001579241
ADS | Alliance Data Systems | reports | Information Technology | Data Processing & Outsourced Services | Plano, Texas | 2013-12-23 | 0001101215
ALL | Allstate Corp | reports | Financials | Property & Casualty Insurance | Northfield Township, Illinois |  | 0000899051
GOOGL | Alphabet Inc Class A | reports | Information Technology | Internet Software & Services | Mountain View, California | 2014-04-03 | 0001652044
GOOG | Alphabet Inc Class C | reports | Information Technology | Internet Software & Services | Mountain View, California |  | 0001652044
MO | Altria Group Inc | reports | Consumer Staples | Tobacco | Richmond, Virginia |  | 0000764180
AMZN | Amazon.com Inc | reports | Consumer Discretionary | Internet & Direct Marketing Retail | Seattle, Washington | 2005-11-18 | 0001018724
AEE | Ameren Corp | reports | Utilities | MultiUtilities | St. Louis, Missouri | 1991-09-19 | 0001002910
AAL | American Airlines Group | reports | Industrials | Airlines | Fort Worth, Texas | 2015-03-23 | 0000006201
AEP | American Electric Power | reports | Utilities | Electric Utilities | Columbus, Ohio |  | 0000004904
AXP | American Express Co | reports | Financials | Consumer Finance | New York, New York | 1976-06-30 | 0000004962
AIG | American International Group, Inc. | reports | Financials | Property & Casualty Insurance | New York, New York | 1980-03-31 | 0000005272
AMT | American Tower Corp A | reports | Real Estate | Specialized REITs | Boston, Massachusetts | 2007-11-19 | 0001053507
AWK | American Water Works Company Inc | reports | Utilities | Water Utilities | Voorhees, New Jersey | 2016-03-04 | 0001410636
AMP | Ameriprise Financial | reports | Financials | Asset Management & Custody Banks | Minneapolis, Minnesota |  | 0000820027
ABC | AmerisourceBergen Corp | reports | Health Care | Health Care Distributors | Chesterbrook, Pennsylvania |  | 0001140859
AME | Ametek | reports | Industrials | Electrical Components & Equipment | Berwyn, Pennsylvania | 2013-09-23 | 0001037868
AMGN | Amgen Inc | reports | Health Care | Biotechnology | Thousand Oaks, California | 1992-01-02 | 0000318154
APH | Amphenol Corp A | reports | Industrials | Electrical Components & Equipment | Wallingford, Connecticut | 2008-09-30 | 0000820313
APC | Anadarko Petroleum Corp | reports | Energy | Oil & Gas Exploration & Production | The Woodlands, Texas |  | 0000773910
ADI | Analog Devices, Inc. | reports | Information Technology | Semiconductors | Norwood, Massachusetts |  | 0000006281
ANTM | Anthem Inc. | reports | Health Care | Managed Health Care | Indianapolis, Indiana |  | 0001156039
AON | Aon plc | reports | Financials | Insurance Brokers | London, United Kingdom |  | 0000315293
APA | Apache Corporation | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas |  | 0000006769
AIV | Apartment Investment & Mgmt | reports | Real Estate | REITs | Denver, Colorado |  | 0000922864
AAPL | Apple Inc. | reports | Information Technology | Computer Hardware | Cupertino, California | 1982-11-30 | 0000320193
AMAT | Applied Materials Inc | reports | Information Technology | Semiconductor Equipment | Santa Clara, California |  | 0000006951
ADM | Archer-Daniels-Midland Co | reports | Consumer Staples | Agricultural Products | Decatur, Illinois | 1981-07-29 | 0000007084
ARNC | Arconic Inc | reports | Industrials | Aerospace & Defense | New York, New York | 1964-03-31 | 0000004281
AJG | Arthur J. Gallagher & Co. | reports | Financials | Insurance Brokers | Itasca, Illinois | 2016-05-31 | 0000354190
AIZ | Assurant Inc | reports | Financials | Multi-line Insurance | New York, New York | 2007-04-10 | 0001267238
T | AT&T Inc | [1] | Telecommunications Services | Integrated Telecommunications Services | Dallas, Texas | 1983-11-30 | 0000732717
ADSK | Autodesk Inc | reports | Information Technology | Application Software | San Rafael, California | 1989-12-01 | 0000769397
ADP | Automatic Data Processing | reports | Information Technology | Internet Software & Services | Roseland, New Jersey | 1981-03-31 | 0000008670
AN | AutoNation Inc | reports | Consumer Discretionary | Specialty Stores | Fort Lauderdale, Florida |  | 0000350698
AZO | AutoZone Inc | reports | Consumer Discretionary | Specialty Stores | Memphis, Tennessee |  | 0000866787
AVB | AvalonBay Communities, Inc. | reports | Real Estate | Residential REITs | Arlington, Virginia[3] | 2007-01-10 | 0000915912
AVY | Avery Dennison Corp | reports | Materials | Paper Packaging | Glendale, California | 1987-12-31 | 0000008818
BHI | Baker Hughes Inc | reports | Energy | Oil & Gas Equipment & Services | Houston, Texas |  | 0000808362
BLL | Ball Corp | reports | Materials | Metal & Glass Containers | Broomfield, Colorado | 1984-10-31 | 0000009389
BAC | Bank of America Corp | reports | Financials | Banks | Charlotte, North Carolina | 1976-06-30 | 0000070858
BK | The Bank of New York Mellon Corp. | reports | Financials | Banks | New York, New York |  | 0001390777
BCR | Bard (C.R.) Inc. | reports | Health Care | Health Care Equipment | Murray Hill, New Jersey | 1975-06-30 | 0000009892
BAX | Baxter International Inc. | reports | Health Care | Health Care Equipment | Deerfield, Illinois | 1972-09-30 | 0000010456
BBT | BB&T Corporation | reports | Financials | Banks | Winston-Salem, North Carolina |  | 0000092230
BDX | Becton Dickinson | reports | Health Care | Health Care Equipment | Franklin Lakes, New Jersey | 1972-09-30 | 0000010795
BBBY | Bed Bath & Beyond | reports | Consumer Discretionary | Specialty Stores | Union, New Jersey |  | 0000886158
BRK-B | Berkshire Hathaway | reports | Financials | Multi-Sector Holdings | Omaha, Nebraska | 2010-02-16 | 0001067983
BBY | Best Buy Co. Inc. | reports | Consumer Discretionary | Computer & Electronics Retail | Richfield, Minnesota |  | 0000764478
BIIB | BIOGEN IDEC Inc. | reports | Health Care | Biotechnology | Weston, Massachusetts |  | 0000875045
BLK | BlackRock | reports | Financials | Asset Management & Custody Banks | New York, New York | 2011-04-04 | 0001364742
HRB | Block H&R | reports | Financials | Consumer Finance | Kansas City, Missouri | 1986-11-30 | 0000012659
BA | Boeing Company | reports | Industrials | Aerospace & Defense | Chicago, Illinois |  | 0000012927
BWA | BorgWarner | reports | Consumer Discretionary | Auto Parts & Equipment | Auburn Hills, Michigan | 2011-12-19 | 0000908255
BXP | Boston Properties | reports | Real Estate | REITs | Boston, Massachusetts |  | 0001037540
BSX | Boston Scientific | reports | Health Care | Health Care Equipment | Marlborough, Massachusetts[4] |  | 0000885725
BMY | Bristol-Myers Squibb | reports | Health Care | Health Care Distributors | New York, New York |  | 0000014272
AVGO | Broadcom | reports | Information Technology | Semiconductors | San Jose, California | 2014-05-08 | 0001441634
BF-B | Brown-Forman Corporation | reports | Consumer Staples | Distillers & Vintners | Louisville, Kentucky | 1982-10-31 | 0000014693
CHRW | C. H. Robinson Worldwide | reports | Industrials | Air Freight & Logistics | Eden Prairie, Minnesota |  | 0001043277
CA | CA, Inc. | reports | Information Technology | Systems Software | Islandia, New York | 1987-07-31 | 0000356028
COG | Cabot Oil & Gas | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas | 2008-06-23 | 0000858470
CPB | Campbell Soup | reports | Consumer Staples | Packaged Foods & Meats | Camden, New Jersey |  | 0000016732
COF | Capital One Financial | reports | Financials | Consumer Finance | Tysons Corner, Virginia |  | 0000927628
CAH | Cardinal Health Inc. | reports | Health Care | Health Care Distributors | Dublin, Ohio |  | 0000721371
HSIC | Henry Schein | reports | Health Care | Health Care Distributors | Melville, New York | 2015-03-17 | 0001000228
KMX | Carmax Inc | reports | Consumer Discretionary | Specialty Stores | Richmond, Virginia | 2010-06-28 | 0001170010
CCL | Carnival Corp. | reports | Consumer Discretionary | Hotels, Resorts & Cruise Lines | Miami, Florida |  | 0000815097
CAT | Caterpillar Inc. | reports | Industrials | Construction & Farm Machinery & Heavy Trucks | Peoria, Illinois |  | 0000018230
CBG | CBRE Group | reports | Real Estate | Real Estate Services | Los Angeles, California |  | 0001138118
CBS | CBS Corp. | reports | Consumer Discretionary | Broadcasting & Cable TV | New York, New York | 1994-09-01 | 0000813828
CELG | Celgene Corp. | reports | Health Care | Biotechnology | Summit, New Jersey |  | 0000816284
CNC | Centene Corporation | reports | Health Care | Managed Health Care | St Louis, Missouri | 2016-03-30 | 0001071739
CNP | CenterPoint Energy | reports | Utilities | MultiUtilities | Houston, Texas | 1985-07-31 | 0001130310
CTL | CenturyLink Inc | reports | Telecommunications Services | Integrated Telecommunications Services | Monroe, Louisiana |  | 0000018926
CERN | Cerner | reports | Health Care | Health Care Distributors | North Kansas City, Missouri | 2010-04-30 | 0000804753
CF | CF Industries Holdings Inc | reports | Materials | Fertilizers & Agricultural Chemicals | Deerfield, Illinois | 2008-08-27 | 0001324404
SCHW | Charles Schwab Corporation | reports | Financials | Investment Banking & Brokerage | San Francisco, California |  | 0000316709
CHTR | Charter Communications | reports | Consumer Discretionary | Cable & Satellite | Stamford, Connecticut | 2016-09-08 | 0001091667
CHK | Chesapeake Energy | reports | Energy | Integrated Oil & Gas | Oklahoma City, Oklahoma |  | 0000895126
CVX | Chevron Corp. | reports | Energy | Integrated Oil & Gas | San Ramon, California |  | 0000093410
CMG | Chipotle Mexican Grill | reports | Consumer Discretionary | Restaurants | Denver, Colorado | 2011-04-28 | 0001058090
CB | Chubb Limited | reports | Financials | Property & Casualty Insurance | Zurich, Switzerland | 2010-07-15 | 0000896159
CHD | Church & Dwight | reports | Consumer Staples | Household Products | Ewing, New Jersey | 2015-12-29 | 0000313927
CI | CIGNA Corp. | reports | Health Care | Managed Health Care | Philadelphia, Pennsylvania | 1976-06-30 | 0000701221
XEC | Cimarex Energy | reports | Energy | Oil & Gas Exploration & Production | Denver, Colorado | 2014-06-21 | 0001168054
CINF | Cincinnati Financial | reports | Financials | Property & Casualty Insurance | Fairfield, Ohio |  | 0000020286
CTAS | Cintas Corporation | reports | Industrials | Diversified Support Services | Mason, Ohio |  | 0000723254
CSCO | Cisco Systems | reports | Information Technology | Networking Equipment | San Jose, California | 1993-12-01 | 0000858877
C | Citigroup Inc. | reports | Financials | Banks | New York, New York | 1988-05-31 | 0000831001
CFG | Citizens Financial Group | reports | Financials | Banks | Providence, Rhode Island | 2016-01-29 | 0000759944
CTXS | Citrix Systems | reports | Information Technology | Internet Software & Services | Fort Lauderdale, Florida |  | 0000877890
CLX | The Clorox Company | reports | Consumer Staples | Household Products | Oakland, California | 1969-03-31 | 0000021076
CME | CME Group Inc. | reports | Financials | Financial Exchanges & Data | Chicago, Illinois |  | 0001156375
CMS | CMS Energy | reports | Utilities | MultiUtilities | Jackson, Michigan |  | 0000811156
COH | Coach Inc. | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | New York, New York |  | 0001116132
KO | Coca Cola Company | reports | Consumer Staples | Soft Drinks | Atlanta, Georgia |  | 0000021344
CTSH | Cognizant Technology Solutions | reports | Information Technology | IT Consulting & Other Services | Teaneck, New Jersey |  | 0001058290
CL | Colgate-Palmolive | reports | Consumer Staples | Household Products | New York, New York |  | 0000021665
CMCSA | Comcast A Corp | reports | Consumer Discretionary | Cable & Satellite | Philadelphia, Pennsylvania |  | 0001166691
CMA | Comerica Inc. | reports | Financials | Regional Banks | Dallas, Texas |  | 0000028412
CAG | ConAgra Foods Inc. | reports | Consumer Staples | Packaged Foods & Meats | Omaha, Nebraska | 1983-08-31 | 0000023217
CXO | Concho Resources | reports | Energy | Oil & Gas Exploration & Production | Midland, Texas | 2016-02-22 | 0001358071
COP | ConocoPhillips | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas |  | 0001163165
ED | Consolidated Edison | reports | Utilities | Electric Utilities | New York, New York |  | 0001047862
STZ | Constellation Brands | reports | Consumer Staples | Distillers & Vintners | Victor, New York |  | 0000016918
GLW | Corning Inc. | reports | Industrials | Construction & Engineering | Corning, New York |  | 0000024741
COST | Costco Co. | reports | Consumer Staples | Hypermarkets & Super Centers | Issaquah, Washington | 1993-10-01 | 0000909832
COTY | Coty, Inc | reports | Consumer Staples | Personal Products | New York, NY | 2016-10-03 | 0001024305
CCI | Crown Castle International Corp. | reports | Real Estate | REITs | Houston, Texas | 2012-03-14 | 0001051470
CSRA | CSRA Inc. | reports | Information Technology | IT Consulting & Services | Falls Church, Virginia | 2015-12-01 | 0001646383
CSX | CSX Corp. | reports | Industrials | Railroads | Jacksonville, Florida | 1967-09-30 | 0000277948
CMI | Cummins Inc. | reports | Industrials | Industrial Machinery | Columbus, Indiana | 1965-03-31 | 0000026172
CVS | CVS Health | reports | Consumer Staples | Drug Retail | Woonsocket, Rhode Island |  | 0000064803
DHI | D. R. Horton | reports | Consumer Discretionary | Homebuilding | Fort Worth, Texas |  | 0000882184
DHR | Danaher Corp. | reports | Industrials | Industrial Machinery | Washington, D.C. |  | 0000313616
DRI | Darden Restaurants | reports | Consumer Discretionary | Restaurants | Orlando, Florida |  | 0000940944
DVA | DaVita Inc. | reports | Health Care | Health Care Facilities | Denver, Colorado | 2008-07-31 | 0000927066
DE | Deere & Co. | reports | Industrials | Construction & Farm Machinery & Heavy Trucks | Moline, Illinois |  | 0000315189
DLPH | Delphi Automotive | reports | Consumer Discretionary | Auto Parts & Equipment | Gillingham, Kent, United Kingdom | 2012-12-24 | 0001521332
DAL | Delta Air Lines | reports | Industrials | Airlines | Atlanta, Georgia | 2013-09-11 | 0000027904
XRAY | Dentsply Sirona | reports | Health Care | Health Care Supplies | York, Pennsylvania | 2008-11-14 | 0000818479
DVN | Devon Energy Corp. | reports | Energy | Oil & Gas Exploration & Production | Oklahoma City, Oklahoma |  | 0001090012
DLR | Digital Realty Trust | reports | Real Estate | Specialized REITs | San Francisco, California | 2016-05-18 | 0001297996
DFS | Discover Financial Services | reports | Financials | Consumer Finance | Riverwoods, Illinois | 2007-07-02 | 0001393612
DISCA | Discovery Communications-A | reports | Consumer Discretionary | Cable & Sataellite | Silver Spring, Maryland | 2010-03-01 | 0001437107
DISCK | Discovery Communications-C | reports | Consumer Discretionary | Cable & Sataellite | Silver Spring, Maryland | 2014-08-07 | 0001437107
DG | Dollar General | reports | Consumer Discretionary | General Merchandise Stores | Goodlettsville, Tennessee | 2012-12-03 | 0000029534
DLTR | Dollar Tree | reports | Consumer Discretionary | General Merchandise Stores | Chesapeake, Virginia | 2011-12-19 | 0000935703
D | Dominion Resources | reports | Utilities | Electric Utilities | Richmond, Virginia |  | 0000715957
DOV | Dover Corp. | reports | Industrials | Industrial Machinery | Downers Grove, Illinois | 1985-10-31 | 0000029905
DOW | Dow Chemical | reports | Materials | Diversified Chemicals | Midland, Michigan |  | 0000029915
DPS | Dr Pepper Snapple Group | reports | Consumer Staples | Soft Drinks | Plano, Texas | 2008-10-07 | 0001418135
DTE | DTE Energy Co. | reports | Utilities | MultiUtilities | Detroit, Michigan |  | 0000936340
DD | Du Pont (E.I.) | reports | Materials | Diversified Chemicals | Wilmington, Delaware |  | 0000030554
DUK | Duke Energy | reports | Utilities | Electric Utilities | Charlotte, North Carolina | 1976-06-30 | 0001326160
DNB | Dun & Bradstreet | reports | Industrials | Data Processing Services | Short Hills, New Jersey | 2008-12-02 | 0001115222
ETFC | E*Trade | reports | Financials | Investment Banking & Brokerage | New York, New York | 2004-03-31 | 0001015780
EMN | Eastman Chemical | reports | Materials | Diversified Chemicals | Kingsport, Tennessee | 1994-01-01 | 0000915389
ETN | Eaton Corporation | reports | Industrials | Industrial Conglomerates | Dublin, Ireland |  | 0001551182
EBAY | eBay Inc. | reports | Information Technology | Internet Software & Services | San Jose, California |  | 0001065088
ECL | Ecolab Inc. | reports | Materials | Specialty Chemicals | St. Paul, Minnesota | 1989-01-31 | 0000031462
EIX | Edison Int'l | reports | Utilities | Electric Utilities | Rosemead, California |  | 0000827052
EW | Edwards Lifesciences | reports | Health Care | Health Care Equipment & Services | Irvine, California | 2011-04-01 | 0001099800
EA | Electronic Arts | reports | Information Technology | Home Entertainment Software | Redwood City, California |  | 0000712515
EMR | Emerson Electric Company | reports | Industrials | Industrial Conglomerates | Ferguson, Missouri | 1965-03-31 | 0000032604
ENDP | Endo International | reports | Health Care | Pharmaceuticals | Dublin, Ireland | 2015-01-27 | 0001100962
ETR | Entergy Corp. | reports | Utilities | Electric Utilities | New Orleans, Louisiana |  | 0000065984
EOG | EOG Resources | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas |  | 0000821189
EQT | EQT Corporation | reports | Energy | Oil & Gas Exploration & Production | Pittsburgh, Pennsylvania | 2008-12-19 | 0000033213
EFX | Equifax Inc. | reports | Financials | Diversified Financial Services | Atlanta, Georgia |  | 0000033185
EQIX | Equinix | reports | Real Estate | REITs | Redwood City, California | 2015-03-20 | 0001101239
EQR | Equity Residential | reports | Real Estate | REITs | Chicago, Illinois |  | 0000906107
ESS | Essex Property Trust Inc | reports | Real Estate | Residential REITs | Palo Alto, California | 2014-04-02 | 0000920522
EL | Estee Lauder Cos. | reports | Consumer Staples | Personal Products | New York, New York |  | 0001001250
ES | Eversource Energy | reports | Utilities | MultiUtilities | Springfield, Massachusetts |  | 0000072741
EXC | Exelon Corp. | reports | Utilities | MultiUtilities | Chicago, Illinois |  | 0001109357
EXPE | Expedia Inc. | reports | Consumer Discretionary | Internet & Direct Marketing Retail | Bellevue, Washington | 2007-10-02 | 0001324424
EXPD | Expeditors Int'l | reports | Industrials | Air Freight & Logistics | Seattle, Washington | 2007-10-10 | 0000746515
ESRX | Express Scripts | reports | Health Care | Health Care Distributors & Services | Cool Valley, Missouri |  | 0001532063
EXR | Extra Space Storage | reports | Real Estate | Specialized REITs | Salt Lake City, UT | 2016-01-19 | 0001289490
XOM | Exxon Mobil Corp. | reports | Energy | Integrated Oil & Gas | Irving, Texas |  | 0000034088
FFIV | F5 Networks | reports | Information Technology | Networking Equipment | Seattle, Washington | 2010-12-20 | 0001048695
FB | Facebook | reports | Information Technology | Internet Software & Services | Menlo Park, California | 2013-12-23 | 0001326801
FAST | Fastenal Co | reports | Industrials | Building Products | Winona, Minnesota | 2009-09-15 | 0000815556
FRT | Federal Realty Investment Trust | reports | Real Estate | Retail REITs | Rockville, Maryland | 2016-02-01 | 0000034903
FDX | FedEx Corporation | reports | Industrials | Air Freight & Logistics | Memphis, Tennessee | 1980-12-31 | 0001048911
FIS | Fidelity National Information Services | reports | Information Technology | Internet Software & Services | Jacksonville, Florida |  | 0001136893
FITB | Fifth Third Bancorp | reports | Financials | Banks | Cincinnati, Ohio |  | 0000035527
FSLR | First Solar Inc | reports | Information Technology | Semiconductors | Tempe, Arizona | 2009-10-16 | 0001274494
FE | FirstEnergy Corp | reports | Utilities | Electric Utilities | Akron, Ohio |  | 0001031296
FISV | Fiserv Inc | reports | Information Technology | Internet Software & Services | Brookfield, Wisconsin |  | 0000798354
FLIR | FLIR Systems | reports | Industrials | Aerospace & Defense | Wilsonville, Oregon | 2009-01-02 | 0000354908
FLS | Flowserve Corporation | reports | Industrials | Industrial Machinery | Irving, Texas | 2008-10-02 | 0000030625
FLR | Fluor Corp. | reports | Industrials | Diversified Commercial Services | Irving, Texas | 1980-03-31 | 0001124198
FMC | FMC Corporation | reports | Materials | Diversified Chemicals | Philadelphia, Pennsylvania | 2009-08-19 | 0000037785
FTI | FMC Technologies Inc. | reports | Energy | Oil & Gas Equipment & Services | Houston, Texas | 2009-06-05 | 0001135152
FL | Foot Locker Inc | reports | Consumer Discretionary | Apparel Retail | New York, New York | 2016-04-04 | 0000850209
F | Ford Motor | reports | Consumer Discretionary | Automobile Manufacturers | Dearborn, Michigan |  | 0000037996
FTV | Fortive Corp | reports | Industrials | Industrial Machinery | Everett, Washington | 2016-07-01 | 0001659166
FBHS | Fortune Brands Home & Security | reports | Industrials | Building Products | Deerfield, Illinois | 2016-06-22 | 0001519751
BEN | Franklin Resources | reports | Financials | Asset Management & Custody Banks | San Mateo, California |  | 0000038777
FCX | Freeport-McMoran Cp & Gld | reports | Materials | Copper | Phoenix, Arizona |  | 0000831259
FTR | Frontier Communications | reports | Telecommunications Services | Integrated Telecommunications Services | Stamford, Connecticut |  | 0000020520
GPS | Gap (The) | reports | Consumer Discretionary | Apparel Retail | San Francisco, California | 1986-08-31 | 0000039911
GRMN | Garmin Ltd. | reports | Consumer Discretionary | Consumer Electronics | Schaffhausen, Switzerland | 2012-12-12 | 0001121788
GD | General Dynamics | reports | Industrials | Aerospace & Defense | Falls Church, Virginia |  | 0000040533
GE | General Electric | reports | Industrials | Industrial Conglomerates | Fairfield, Connecticut |  | 0000040545
GGP | General Growth Properties Inc. | reports | Real Estate | REITs | Chicago, Illinois | 2013-12-10 | 0000895648
GIS | General Mills | reports | Consumer Staples | Packaged Foods & Meats | Golden Valley, Minnesota | 1969-03-31 | 0000040704
GM | General Motors | reports | Consumer Discretionary | Automobile Manufacturers | Detroit, Michigan | 2013-06-06 | 0001467858
GPC | Genuine Parts | reports | Consumer Discretionary | Specialty Stores | Atlanta, Georgia | 1973-12-31 | 0000040987
GILD | Gilead Sciences | reports | Health Care | Biotechnology | Foster City, California |  | 0000882095
GPN | Global Payments Inc | reports | Information Technology | Data Processing & Outsourced Services | Atlanta, Georgia | 2016-04-25 | 0001123360
GS | Goldman Sachs Group | reports | Financials | Investment Banking & Brokerage | New York, New York |  | 0000886982
GT | Goodyear Tire & Rubber | reports | Consumer Discretionary | Tires & Rubber | Akron, Ohio |  | 0000042582
GWW | Grainger (W.W.) Inc. | reports | Industrials | Industrial Materials | Lake Forest, Illinois | 1981-06-30 | 0000277135
HAL | Halliburton Co. | reports | Energy | Oil & Gas Equipment & Services | Houston, Texas |  | 0000045012
HBI | Hanesbrands Inc | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | Winston-Salem, North Carolina | 2015-03-20 | 0001359841
HOG | Harley-Davidson | reports | Consumer Discretionary | Motorcycle Manufacturers | Milwaukee, Wisconsin |  | 0000793952
HAR | Harman Int'l Industries | reports | Consumer Discretionary | Consumer Electronics | Stamford, Connecticut |  | 0000800459
HRS | Harris Corporation | reports | Information Technology | Telecommunications Equipment | Melbourne, Florida | 2008-09-22 | 0000202058
HIG | Hartford Financial Svc.Gp. | reports | Financials | Property & Casualty Insurance | Hartford, Connecticut |  | 0000874766
HAS | Hasbro Inc. | reports | Consumer Discretionary | Leisure Products | Pawtucket, Rhode Island | 1984-09-30 | 0000046080
HCA | HCA Holdings | reports | Health Care | Health Care Facilities | Nashville, Tennessee | 2015-01-27 | 0000860730
HCP | HCP Inc. | reports | Real Estate | REITs | Long Beach, California | 2008-03-31 | 0000765880
HP | Helmerich & Payne | reports | Energy | Oil & Gas Drilling | Tulsa, Oklahoma[5] |  | 0000046765
HES | Hess Corporation | reports | Energy | Integrated Oil & Gas | New York, New York | 1984-05-31 | 0000004447
HPE | Hewlett Packard Enterprise | reports | Information Technology | Technology Hardware, Storage & Peripherals | Palo Alto, California | 2015-11-02 | 0001645590
HOLX | Hologic | reports | Health Care | Health Care Equipment | Marlborough, Massachusetts | 2016-03-30 | 0000859737
HD | Home Depot | reports | Consumer Discretionary | Home Improvement Retail | Atlanta, Georgia | 1988-03-31 | 0000354950
HON | Honeywell Int'l Inc. | reports | Industrials | Industrial Conglomerates | Morristown, New Jersey | 1964-03-31 | 0000773840
HRL | Hormel Foods Corp. | reports | Consumer Staples | Packaged Foods & Meats | Austin, Minnesota | 2009-03-04 | 0000048465
HST | Host Hotels & Resorts | reports | Real Estate | REITs | Bethesda, Maryland | 2007-03-20 | 0001070750
HPQ | HP Inc. | reports | Information Technology | Computer Hardware | Palo Alto, California | 1974-12-31 | 0000047217
HUM | Humana Inc. | reports | Health Care | Managed Health Care | Louisville, Kentucky |  | 0000049071
HBAN | Huntington Bancshares | reports | Financials | Banks | Columbus, Ohio |  | 0000049196
ITW | Illinois Tool Works | reports | Industrials | Industrial Machinery | Glenview, Illinois | 1986-02-28 | 0000049826
ILMN | Illumina Inc | reports | Health Care | Life Sciences Tools & Services | San Diego, California | 2015-11-19 | 0001110803
IR | Ingersoll-Rand PLC | reports | Industrials | Industrial Conglomerates | Dublin, Ireland | 2010-11-17 | 0001466258
INTC | Intel Corp. | reports | Information Technology | Semiconductors | Santa Clara, California | 1976-12-31 | 0000050863
ICE | Intercontinental Exchange | reports | Financials | Diversified Financial Services | Atlanta, Georgia | 2007-09-26 | 0001571949
IBM | International Bus. Machines | reports | Information Technology | IT Consulting & Services | Armonk, New York |  | 0000051143
IP | International Paper | reports | Materials | Paper Products | Memphis, Tennessee |  | 0000051434
IPG | Interpublic Group | reports | Consumer Discretionary | Advertising | New York, New York | 1992-10-01 | 0000051644
IFF | Intl Flavors & Fragrances | reports | Materials | Specialty Chemicals | New York, New York | 1976-03-31 | 0000051253
INTU | Intuit Inc. | reports | Information Technology | Internet Software & Services | Mountain View, California | 2000-12-05 | 0000896878
ISRG | Intuitive Surgical Inc. | reports | Health Care | Health Care Equipment & Services | Sunnyvale, California | 2008-06-02 | 0001035267
IVZ | Invesco Ltd. | reports | Financials | Asset Management & Custody Banks | Atlanta, Georgia | 2008-08-21 | 0000914208
IRM | Iron Mountain Incorporated | reports | Real Estate | REITs | Boston, Massachusetts | 2009-01-06 | 0001020569
JEC | Jacobs Engineering Group | reports | Industrials | Industrial Conglomerates | Pasadena, California | 2007-10-26 | 0000052988
JBHT | J. B. Hunt Transport Services | reports | Industrials | Trucking | Lowell, Arkansas | 2015-07-01 | 0000728535
SJM | JM Smucker | reports | Consumer Staples | Packaged Foods & Meats | Orrville, Ohio | 2008-11-06 | 0000091419
JNJ | Johnson & Johnson | reports | Health Care | Health Care Equipment & Services | New Brunswick, New Jersey | 1973-06-30 | 0000200406
JCI | Johnson Controls International Plc | reports | Consumer Discretionary | Building Products | Milwaukee, Wisconsin | 2010-08-27 | 0000833444
JPM | JPMorgan Chase & Co. | reports | Financials | Banks | New York, New York | 1975-06-30 | 0000019617
JNPR | Juniper Networks | reports | Information Technology | Networking Equipment | Sunnyvale, California |  | 0001043604
KSU | Kansas City Southern | reports | Industrials | Railroads | Kansas City, Missouri | 2013-05-24 | 0000054480
K | Kellogg Co. | reports | Consumer Staples | Packaged Foods & Meats | Battle Creek, Michigan |  | 0000055067
KEY | KeyCorp | reports | Financials | Banks | Cleveland, Ohio | 1994-03-01 | 0000091576
KMB | Kimberly-Clark | reports | Consumer Staples | Household Products | Irving, Texas |  | 0000055785
KIM | Kimco Realty | reports | Real Estate | REITs | New Hyde Park, New York |  | 0000879101
KMI | Kinder Morgan | reports | Energy | Oil & Gas Refining & Marketing & Transportation | Houston, Texas | 2012-05-25 | 0001506307
KLAC | KLA-Tencor Corp. | reports | Information Technology | Semiconductor Equipment | Milpitas, California |  | 0000319201
KSS | Kohl's Corp. | reports | Consumer Discretionary | General Merchandise Stores | Menomonee Falls, Wisconsin |  | 0000885639
KHC | Kraft Heinz Co | reports | Consumer Staples | Packaged Foods & Meats | Pittsburgh, Pennsylvania | 2012-10-02 | 0001545158
KR | Kroger Co. | reports | Consumer Staples | Food Retail | Cincinnati, Ohio |  | 0000056873
LB | L Brands Inc. | reports | Consumer Discretionary | Apparel Retail | Columbus, Ohio | 1983-09-30 | 0000701985
LLL | L-3 Communications Holdings | reports | Industrials | Industrial Conglomerates | New York, New York |  | 0001056239
LH | Laboratory Corp. of America Holding | reports | Health Care | Health Care Facilities | Burlington, North Carolina |  | 0000920148
LRCX | Lam Research | reports | Information Technology | Semiconductor Equipment | Fremont, California | 2012-06-29 | 0000707549
LM | Legg Mason | reports | Financials | Asset Management & Custody Banks | Baltimore, Maryland |  | 0000704051
LEG | Leggett & Platt | reports | Industrials | Industrial Conglomerates | Carthage, Missouri |  | 0000058492
LEN | Lennar Corp. | reports | Consumer Discretionary | Homebuilding | Miami, Florida |  | 0000920760
LVLT | Level 3 Communications | reports | Telecommunications Services | Alternative Carriers | Broomfield, Colorado | 2014-11-05 | 0000794323
LUK | Leucadia National Corp. | reports | Financials | Multi-Sector Holdings | New York, New York | 2007-08-27 | 0000096223
LLY | Lilly (Eli) & Co. | reports | Health Care | Pharmaceuticals | Indianapolis, Indiana | 1970-12-31 | 0000059478
LNC | Lincoln National | reports | Financials | Multi-line Insurance | Radnor, Pennsylvania | 1976-06-30 | 0000059558
LLTC | Linear Technology Corp. | reports | Information Technology | Semiconductors | Milpitas, California |  | 0000791907
LKQ | LKQ Corporation | reports | Consumer Discretionary | Distributors | Chicago, Illinois | 2016-05-23 | 0001065696
LMT | Lockheed Martin Corp. | reports | Industrials | Aerospace & Defense | Bethesda, Maryland | 1984-07-31 | 0000936468
L | Loews Corp. | reports | Financials | Multi-Sector Holdings | New York, New York |  | 0000060086
LOW | Lowe's Cos. | reports | Consumer Discretionary | Home Improvement Retail | Mooresville, North Carolina | 1984-02-29 | 0000060667
LYB | LyondellBasell | reports | Materials | Diversified Chemicals | Rotterdam, Netherlands | 2012-09-05 | 0001489393
MTB | M&T Bank Corp. | reports | Financials | Banks | Buffalo, New York |  | 0000036270
MAC | Macerich | reports | Real Estate | Retail REITs | Santa Monica, California | 2013-05-09 | 0000912242
M | Macy's Inc. | reports | Consumer Discretionary | Department Stores | Cincinnati, Ohio |  | 0000794367
MNK | Mallinckrodt Plc | reports | Health Care | Pharmaceuticals | Dublin, Ireland | 2014-08-19 | 0001567892
MRO | Marathon Oil Corp. | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas | 1991-05-01 | 0000101778
MPC | Marathon Petroleum | reports | Energy | Oil & Gas Refining & Marketing & Transportation | Findlay, Ohio | 2011-07-01 | 0001510295
MAR | Marriott Int'l. | reports | Consumer Discretionary | Hotels, Resorts & Cruise Lines | Bethesda, Maryland |  | 0001048286
MMC | Marsh & McLennan | reports | Financials | Insurance Brokers | New York, New York | 1987-08-31 | 0000062709
MLM | Martin Marietta Materials | reports | Materials | Construction Materials | Raleigh, North Carolina | 2014-07-02 | 0000916076
MAS | Masco Corp. | reports | Industrials | Building Products | Taylor, Michigan | 1981-06-30 | 0000062996
MA | Mastercard Inc. | reports | Information Technology | Internet Software & Services | Harrison, New York | 2008-07-18 | 0001141391
MAT | Mattel Inc. | reports | Consumer Discretionary | Leisure Products | El Segundo, California | 1982-03-31 | 0000063276
MKC | McCormick & Co. | reports | Consumer Staples | Packaged Foods & Meats | Sparks, Maryland |  | 0000063754
MCD | McDonald's Corp. | reports | Consumer Discretionary | Restaurants | Oak Brook, Illinois | 1970-06-30 | 0000063908
MCK | McKesson Corp. | reports | Health Care | Health Care Distributors & Services | San Francisco, California |  | 0000927653
MJN | Mead Johnson | reports | Consumer Staples | Packaged Foods & Meats | Glenview, Illinois | 2009-12-21 | 0001452575
MDT | Medtronic plc | reports | Health Care | Health Care Equipment & Services | Dublin, Ireland | 1986-10-31 | 0000064670
MRK | Merck & Co. | reports | Health Care | Pharmaceuticals | Whitehouse Station, New Jersey |  | 0000310158
MET | MetLife Inc. | reports | Financials | Life & Health Insurance | New York, New York |  | 0001099219
MTD | Mettler Toledo | reports | Health Care | Life Sciences Tool & Equipment | Columbus, Ohio | 2016-09-06 | 0001037646
KORS | Michael Kors Holdings | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | New York, New York | 2013-11-13 | 0001530721
MCHP | Microchip Technology | reports | Information Technology | Semiconductors | Chandler, Arizona | 2007-09-07 | 0000827054
MU | Micron Technology | reports | Information Technology | Semiconductors | Boise, Idaho | 1994-09-27 | 0000723125
MSFT | Microsoft Corp. | reports | Information Technology | Systems Software | Redmond, Washington | 1994-06-01 | 0000789019
MHK | Mohawk Industries | reports | Consumer Discretionary | Home Furnishings | Amsterdam, New York | 2013-12-23 | 0000851968
TAP | Molson Coors Brewing Company | reports | Consumer Staples | Brewers | Denver, Colorado | 1976-06-30 | 0000024545
MDLZ | Mondelez International | reports | Consumer Staples | Packaged Foods & Meats | Northfield, Illinois | 2012-10-02 | 0001103982
MON | Monsanto Co. | reports | Materials | Fertilizers & Agricultural Chemicals | Creve Coeur, Missouri | 2002-08-07 | 0001110783
MNST | Monster Beverage | reports | Consumer Staples | Soft Drinks | Corona, California | 2012-06-28 | 0000865752
MCO | Moody's Corp | reports | Financials | Diversified Financial Services | New York, New York |  | 0001059556
MS | Morgan Stanley | reports | Financials | Investment Banking & Brokerage | New York, New York |  | 0000895421
MOS | The Mosaic Company | reports | Materials | Fertilizers & Agricultural Chemicals | Plymouth, Minnesota | 2011-09-26 | 0001285785
MSI | Motorola Solutions Inc. | reports | Information Technology | Telecommunications Equipment | Schaumburg, Illinois |  | 0000068505
MUR | Murphy Oil | reports | Energy | Integrated Oil & Gas | El Dorado, Arkansas |  | 0000717423
MYL | Mylan N.V. | reports | Health Care | Pharmaceuticals | Amsterdam, Netherlands |  | 0000069499
NDAQ | NASDAQ OMX Group | reports | Financials | Diversified Financial Services | New York, New York | 2008-10-22 | 0001120193
NOV | National Oilwell Varco Inc. | reports | Energy | Oil & Gas Equipment & Services | Houston, Texas |  | 0001021860
NAVI | Navient | reports | Financials | Consumer Finance | Newark, Delaware | 2014-05-01 | 0001593538
NTAP | NetApp | reports | Information Technology | Internet Software & Services | Sunnyvale, California |  | 0001002047
NFLX | Netflix Inc. | reports | Information Technology | Internet Software & Services | Los Gatos, California | 2010-12-20 | 0001065280
NWL | Newell Rubbermaid Co. | reports | Consumer Discretionary | Housewares & Specialties | Sandy Springs, Georgia | 1989-04-30 | 0000814453
NFX | Newfield Exploration Co | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas | 2010-12-20 | 0000912750
NEM | Newmont Mining Corp. (Hldg. Co.) | reports | Materials | Gold | Denver, Colorado | 1969-06-30 | 0001164727
NWSA | News Corp. Class A | reports | Consumer Discretionary | Publishing | New York, New York | 2013-08-01 | 0001564708
NWS | News Corp. Class B | reports | Consumer Discretionary | Publishing | New York, New York | 2013-08-01 | 0001564708
NEE | NextEra Energy | reports | Utilities | MultiUtilities | Juno Beach, Florida | 1976-06-30 | 0000753308
NLSN | Nielsen Holdings | reports | Industrials | Research & Consulting Services | New York, New York | 2013-07-09 | 0001492633
NKE | Nike | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | Washington County, Oregon | 1988-11-30 | 0000320187
NI | NiSource Inc. | reports | Utilities | MultiUtilities | Merrillville, Indiana |  | 0001111711
NBL | Noble Energy Inc | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas | 2007-10-08 | 0000072207
JWN | Nordstrom | reports | Consumer Discretionary | Department Stores | Seattle, Washington | 1986-08-31 | 0000072333
NSC | Norfolk Southern Corp. | reports | Industrials | Railroads | Norfolk, Virginia |  | 0000702165
NTRS | Northern Trust Corp. | reports | Financials | Asset Management & Custody Banks | Chicago, Illinois |  | 0000073124
NOC | Northrop Grumman Corp. | reports | Industrials | Aerospace & Defense | West Falls Church, Virginia | 1985-06-30 | 0001133421
NRG | NRG Energy | reports | Utilities | Independent Power Producers & Energy Traders | Princeton, New Jersey | 2010-01-29 | 0001013871
NUE | Nucor Corp. | reports | Materials | Steel | Charlotte, North Carolina | 1985-04-30 | 0000073309
NVDA | Nvidia Corporation | reports | Information Technology | Semiconductors | Santa Clara, California |  | 0001045810
ORLY | O'Reilly Automotive | reports | Consumer Discretionary | Specialty Stores | Springfield, Missouri | 2009-03-27 | 0000898173
OXY | Occidental Petroleum | reports | Energy | Oil & Gas Exploration & Production | Los Angeles, California | 1982-12-31 | 0000797468
OMC | Omnicom Group | reports | Consumer Discretionary | Advertising | New York, New York |  | 0000029989
OKE | ONEOK | reports | Energy | Oil & Gas Exploration & Production | Tulsa, Oklahoma | 2010-03-15 | 0001039684
ORCL | Oracle Corp. | reports | Information Technology | Application Software | Redwood Shores, California | 1989-08-31 | 0001341439
OI | Owens-Illinois Inc | reports | Materials | Metal & Glass Containers | Perrysburg, Ohio | 2009-01-02 | 0000812074
PCAR | PACCAR Inc. | reports | Industrials | Construction & Farm Machinery & Heavy Trucks | Bellevue, Washington | 1980-12-31 | 0000075362
PH | Parker-Hannifin | reports | Industrials | Industrial Conglomerates | Cleveland, Ohio | 1985-11-30 | 0000076334
PDCO | Patterson Companies | reports | Health Care | Health Care Supplies | St. Paul, Minnesota |  | 0000891024
PAYX | Paychex Inc. | reports | Information Technology | Internet Software & Services | Penfield, New York |  | 0000723531
PYPL | PayPal | reports | Information Technology | Data Processing & Outsourced Services | San Jose, California | 2015-07-20 | 0001633917
PNR | Pentair Ltd. | reports | Industrials | Industrial Conglomerates | Worsley, UK | 2012-10-01 | 0000077360
PBCT | People's United Financial | reports | Financials | Thrifts & Mortgage Finance | Bridgeport, Connecticut | 2008-11-13 | 0001378946
PEP | PepsiCo Inc. | reports | Consumer Staples | Soft Drinks | Purchase, New York |  | 0000077476
PKI | PerkinElmer | reports | Health Care | Health Care Equipment & Services | Waltham, Massachusetts | 1985-05-31 | 0000031791
PRGO | Perrigo | reports | Health Care | Pharmaceuticals | Dublin, Ireland | 2011-12-19 | 0001585364
PFE | Pfizer Inc. | reports | Health Care | Pharmaceuticals | New York, New York |  | 0000078003
PCG | PG&E Corp. | reports | Utilities | MultiUtilities | San Francisco, California |  | 0001004980
PM | Philip Morris International | reports | Consumer Staples | Tobacco | New York, New York | 2008-03-31 | 0001413329
PSX | Phillips 66 | reports | Energy | Oil & Gas Refining & Marketing & Transportation | Houston, Texas | 2012-05-01 | 0001534701
PNW | Pinnacle West Capital | reports | Utilities | MultiUtilities | Phoenix, Arizona |  | 0000764622
PXD | Pioneer Natural Resources | reports | Energy | Oil & Gas Exploration & Production | Irving, Texas | 2008-09-24 | 0001038357
PBI | Pitney-Bowes | reports | Industrials | Technology, Hardware, Software and Supplies | Stamford, Connecticut |  | 0000078814
PNC | PNC Financial Services | reports | Financials | Banks | Pittsburgh, Pennsylvania | 1988-04-30 | 0000713676
RL | Polo Ralph Lauren Corp. | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | New York, New York | 2007-02-02 | 0001037038
PPG | PPG Industries | reports | Materials | Diversified Chemicals | Pittsburgh, Pennsylvania |  | 0000079879
PPL | PPL Corp. | reports | Utilities | Electric Utilities | Allentown, Pennsylvania |  | 0000922224
PX | Praxair Inc. | reports | Materials | Industrial Gases | Danbury, Connecticut | 1992-07-01 | 0000884905
PCLN | Priceline.com Inc | reports | Consumer Discretionary | Internet & Direct Marketing Retail | Norwalk, Connecticut | 2009-11-06 | 0001075531
PFG | Principal Financial Group | reports | Financials | Diversified Financial Services | Des Moines, Iowa |  | 0001126328
PG | Procter & Gamble | reports | Consumer Staples | Personal Products | Cincinnati, Ohio |  | 0000080424
PGR | Progressive Corp. | reports | Financials | Property & Casualty Insurance | Mayfield Village, Ohio |  | 0000080661
PLD | Prologis | reports | Real Estate | REITs | San Francisco, California |  | 0001045609
PRU | Prudential Financial | reports | Financials | Diversified Financial Services | Newark, New Jersey |  | 0001137774
PEG | Public Serv. Enterprise Inc. | reports | Utilities | Electric Utilities | Newark, New Jersey |  | 0000788784
PSA | Public Storage | reports | Real Estate | REITs | Glendale, California |  | 0001393311
PHM | Pulte Homes Inc. | reports | Consumer Discretionary | Homebuilding | Atlanta, Georgia | 1984-04-30 | 0000822416
PVH | PVH Corp. | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | New York, New York | 2013-02-15 | 0000078239
QRVO | Qorvo | reports | Information Technology | Semiconductors | Hillsboro, Oregon | 2015-06-11 | 0001604778
PWR | Quanta Services Inc. | reports | Industrials | Industrial Conglomerates | Houston, Texas | 2009-07-01 | 0001050915
QCOM | QUALCOMM Inc. | reports | Information Technology | Semiconductors | San Diego, California |  | 0000804328
DGX | Quest Diagnostics | reports | Health Care | Health Care Facilities | Madison, New Jersey |  | 0001022079
RRC | Range Resources Corp. | reports | Energy | Oil & Gas Exploration & Production | Fort Worth, Texas | 2007-12-21 | 0000315852
RTN | Raytheon Co. | reports | Industrials | Aerospace & Defense | Waltham, Massachusetts |  | 0001047122
O | Realty Income Corporation | reports | Real Estate | REITs | San Diego, California | 2015-04-07 | 0000726728
RHT | Red Hat Inc. | reports | Information Technology | Systems Software | Raleigh, North Carolina | 2009-07-27 | 0001087423
REGN | Regeneron | reports | Health Care | Biotechnology | Tarrytown, New York | 2013-05-01 | 0000872589
RF | Regions Financial Corp. | reports | Financials | Diversified Financial Services | Birmingham, Alabama |  | 0001281761
RSG | Republic Services Inc | reports | Industrials | Industrial Conglomerates | Phoenix, Arizona | 2008-12-05 | 0001060391
RAI | Reynolds American Inc. | reports | Consumer Staples | Tobacco | Winston-Salem, North Carolina |  | 0001275283
RHI | Robert Half International | reports | Industrials | Human Resource & Employment Services | Menlo Park, California |  | 0000315213
ROK | Rockwell Automation Inc. | reports | Industrials | Industrial Conglomerates | Milwaukee, Wisconsin |  | 0001024478
COL | Rockwell Collins | reports | Industrials | Industrial Conglomerates | Cedar Rapids, Iowa |  | 0001137411
ROP | Roper Industries | reports | Industrials | Industrial Conglomerates | Sarasota, Florida | 2009-12-23 | 0000882835
ROST | Ross Stores | reports | Consumer Discretionary | Apparel Retail | Pleasanton, California | 2009-12-21 | 0000745732
RCL | Royal Caribbean Cruises Ltd | reports | Consumer Discretionary | Hotels, Resorts & Cruise Lines | Miami, Florida | 2014-12-05 | 0000884887
R | Ryder System | reports | Industrials | Industrial Conglomerates | Miami, Florida | 1982-12-31 | 0000085961
CRM | Salesforce.com | reports | Information Technology | Internet Software & Services | San Francisco, California | 2008-09-15 | 0001108524
SCG | SCANA Corp | reports | Utilities | MultiUtilities | Cayce, South Carolina | 2009-01-02 | 0000754737
SLB | Schlumberger Ltd. | reports | Energy | Oil & Gas Equipment & Services | Curaçao, Kingdom of the Netherlands | 1965-03-31 | 0000087347
SNI | Scripps Networks Interactive Inc. | reports | Consumer Discretionary | Broadcasting & Cable TV | Cincinnati, Ohio | 2008-07-01 | 0001430602
STX | Seagate Technology | reports | Information Technology | Computer Storage & Peripherals | Dublin, Ireland | 2012-07-02 | 0001137789
SEE | Sealed Air | reports | Materials | Paper Packaging | Elmwood Park, New Jersey |  | 0001012100
SRE | Sempra Energy | reports | Utilities | MultiUtilities | San Diego, California |  | 0001032208
SHW | Sherwin-Williams | reports | Materials | Specialty Chemicals | Cleveland, Ohio | 1964-06-30 | 0000089800
SIG | Signet Jewelers | reports | Consumer Discretionary | Specialty Stores | Hamilton, Bermuda | 2015-07-29 | 0000832988
SPG | Simon Property Group Inc | reports | Real Estate | REITs | Indianapolis, Indiana |  | 0001063761
SWKS | Skyworks Solutions | reports | Information Technology | Semiconductors | Woburn, Massachusetts | 2015-03-12 | 0000004127
SLG | SL Green Realty | reports | Real Estate | Office REITs | New York, New York | 2015-03-20 | 0001040971
SNA | Snap-On Inc. | reports | Consumer Discretionary | Household Appliances | Kenosha, Wisconsin | 1982-09-30 | 0000091440
SO | Southern Co. | reports | Utilities | Electric Utilities | Atlanta, Georgia |  | 0000092122
LUV | Southwest Airlines | reports | Industrials | Airlines | Dallas, Texas | 1994-07-01 | 0000092380
SWN | Southwestern Energy | reports | Energy | Oil & Gas Exploration & Production | Houston, Texas[6] | 2008-06-06 | 0000007332
SE | Spectra Energy Corp. | reports | Energy | Oil & Gas Refining & Marketing & Transportation | Houston, Texas |  | 0001373835
SPGI | S&P Global, Inc. | reports | Financials | Diversified Financial Services | New York, New York |  | 0000064040
STJ | St Jude Medical | reports | Health Care | Health Care Equipment & Services | Little Canada, Minnesota | 1989-11-30 | 0000203077
SWK | Stanley Black & Decker | reports | Consumer Discretionary | Household Appliances | New Britain, Connecticut | 1982-09-30 | 0000093556
SPLS | Staples Inc. | reports | Consumer Discretionary | Specialty Stores | Framingham, Massachusetts |  | 0000791519
SBUX | Starbucks Corp. | reports | Consumer Discretionary | Restaurants | Seattle, Washington |  | 0000829224
STT | State Street Corp. | reports | Financials | Diversified Financial Services | Boston, Massachusetts |  | 0000093751
SRCL | Stericycle Inc | reports | Industrials | Industrial Conglomerates | Lake Forest, Illinois | 2008-11-19 | 0000861878
SYK | Stryker Corp. | reports | Health Care | Health Care Equipment & Services | Kalamazoo, Michigan |  | 0000310764
STI | SunTrust Banks | reports | Financials | Banks | Atlanta, Georgia | 1988-05-31 | 0000750556
SYMC | Symantec Corp. | reports | Information Technology | Application Software | Mountain View, California | 2003-03-25 | 0000849399
SYF | Synchrony Financial | reports | Financials | Consumer Finance | Stamford, Connecticut | 2015-11-18 | 0001601712
SYY | Sysco Corp. | reports | Consumer Staples | Food Distributors | Houston, Texas | 1986-12-31 | 0000096021
TROW | T. Rowe Price Group | reports | Financials | Diversified Financial Services | Baltimore, Maryland |  | 0001113169
TGT | Target Corp. | reports | Consumer Discretionary | General Merchandise Stores | Minneapolis, Minnesota | 1976-12-31 | 0000027419
TEL | TE Connectivity Ltd. | reports | Information Technology | Electronic Equipment & Instruments | Schaffhausen, Switzerland | 2011-10-17 | 0001385157
TGNA | Tegna | reports | Consumer Discretionary | Publishing | McLean, Virginia | 1975-12-31 | 0000039899
TDC | Teradata Corp. | reports | Information Technology | Application Software | Miamisburg, Ohio | 2007-10-01 | 0000816761
TSO | Tesoro Petroleum Co. | reports | Energy | Oil & Gas Refining & Marketing & Transportation | San Antonio, Texas | 2007-09-27 | 0000050104
TXN | Texas Instruments | reports | Information Technology | Semiconductors | Dallas, Texas |  | 0000097476
TXT | Textron Inc. | reports | Industrials | Industrial Conglomerates | Providence, Rhode Island | 1978-12-31 | 0000217346
COO | The Cooper Companies | reports | Health Care | Health Care Supplies | Pleasanton, California | 2016-09-23 | 0000711404
HSY | The Hershey Company | reports | Consumer Staples | Packaged Foods & Meats | Hershey, Pennsylvania |  | 0000047111
TRV | The Travelers Companies Inc. | reports | Financials | Property & Casualty Insurance | New York, New York |  | 0000086312
TMO | Thermo Fisher Scientific | reports | Health Care | Health Care Equipment & Services | Waltham, Massachusetts |  | 0000097745
TIF | Tiffany & Co. | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | New York, New York |  | 0000098246
TWX | Time Warner Inc. | reports | Consumer Discretionary | Broadcasting & Cable TV | New York, New York |  | 0001105705
TJX | TJX Companies Inc. | reports | Consumer Discretionary | Apparel Retail | Framingham, Massachusetts | 1985-09-30 | 0000109198
TMK | Torchmark Corp. | reports | Financials | Life & Health Insurance | McKinney, Texas | 1989-04-30 | 0000320335
TSS | Total System Services | reports | Information Technology | Internet Software & Services | Columbus, Georgia | 2008-01-02 | 0000721683
TSCO | Tractor Supply Company | reports | Consumer Discretionary | Specialty Retail | Brentwood, Tennessee | 2014-01-24 | 0000916365
TDG | TransDigm Group | reports | Industrials | Aerospace & Defense | Cleveland, Ohio | 2016-06-03 | 0001260221
RIG | Transocean | reports | Energy | Oil & Gas Drilling | Vernier, Switzerland | 2013-10-29 | 0001451505
TRIP | TripAdvisor | reports | Consumer Discretionary | Internet & Direct Marketing Retail | Newton, Massachusetts | 2011-12-21 | 0001526520
FOXA | Twenty-First Century Fox Class A | reports | Consumer Discretionary | Publishing | New York, New York | 2013-07-01 | 0001308161
FOX | Twenty-First Century Fox Class B | reports | Consumer Discretionary | Publishing | New York, New York | 2013-07-01 | 0001308161
TSN | Tyson Foods | reports | Consumer Staples | Packaged Foods & Meats | Springdale, Arkansas |  | 0000100493
UDR | UDR Inc | reports | Real Estate | Residential REITs | Highlands Ranch, Colorado | 2016-03-07 | 0000074208
ULTA | Ulta Salon Cosmetics & Fragrance Inc | reports | Consumer Discretionary | Specialty Stores | Bolingbrook, Illinois | 2016-04-18 | 0001403568
USB | U.S. Bancorp | reports | Financials | Banks | Minneapolis, Minnesota |  | 0000036104
UA | Under Armour | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | Baltimore, Maryland | 2014-05-01 | 0001336917
UA.C | Under Armour | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | Baltimore, Maryland | 2016-03-25 | 0001336917
UNP | Union Pacific | reports | Industrials | Railroads | Omaha, Nebraska |  | 0000100885
UAL | United Continental Holdings | reports | Industrials | Airlines | Chicago, Illinois | 2015-09-03 | 0000100517
UNH | United Health Group Inc. | reports | Health Care | Managed Health Care | Minnetonka, Minnesota | 1994-07-01 | 0000731766
UPS | United Parcel Service | reports | Industrials | Air Freight & Logistics | Atlanta, Georgia |  | 0001090727
URI | United Rentals, Inc. | reports | Industrials | Trading Companies & Distributors | Stamford, Connecticut | 2014-09-20 | 0001067701
UTX | United Technologies | reports | Industrials | Industrial Conglomerates | Hartford, Connecticut |  | 0000101829
UHS | Universal Health Services, Inc. | reports | Health Care | Health Care Facilities | King of Prussia, Pennsylvania | 2014-09-20 | 0000352915
UNM | Unum Group | reports | Financials | Diversified Financial Services | Chattanooga, Tennessee | 1994-03-01 | 0000005513
URBN | Urban Outfitters | reports | Consumer Discretionary | Apparel Retail | Philadelphia, Pennsylvania | 2010-02-08 | 0000912615
VFC | V.F. Corp. | reports | Consumer Discretionary | Apparel, Accessories & Luxury Goods | Greensboro, North Carolina | 1979-06-30 | 0000103379
VLO | Valero Energy | reports | Energy | Oil & Gas Refining & Marketing & Transportation | San Antonio, Texas |  | 0001035002
VAR | Varian Medical Systems | reports | Health Care | Health Care Equipment & Services | Palo Alto, California | 2007-02-12 | 0000203527
VTR | Ventas Inc | reports | Real Estate | REITs | Chicago, Illinois | 2009-03-04 | 0000740260
VRSN | Verisign Inc. | reports | Information Technology | Internet Software & Services | Dulles, Virginia |  | 0001014473
VRSK | Verisk Analytics | reports | Industrials | Research & Consulting Services | Jersey City, New Jersey | 2015-10-08 | 0001442145
VZ | Verizon Communications | reports | Telecommunications Services | Integrated Telecommunications Services | New York, New York | 1983-11-30 | 0000732712
VRTX | Vertex Pharmaceuticals Inc | reports | Health Care | Biotechnology | Cambridge, Massachusetts | 2013-09-23 | 0000875320
VIAB | Viacom Inc. | reports | Consumer Discretionary | Broadcasting & Cable TV | New York, New York |  | 0001339947
V | Visa Inc. | reports | Information Technology | Internet Software & Services | San Francisco, California | 2009-12-21 | 0001403161
VNO | Vornado Realty Trust | reports | Real Estate | REITs | New York, New York |  | 0000899689
VMC | Vulcan Materials | reports | Materials | Construction Materials | Birmingham, Alabama |  | 0001396009
WMT | Wal-Mart Stores | reports | Consumer Staples | Hypermarkets & Super Centers | Bentonville, Arkansas | 1982-08-31 | 0000104169
WBA | Walgreens Boots Alliance | reports | Consumer Staples | Drug Retail | Deerfield, Illinois | 1979-12-31 | 0001618921
DIS | The Walt Disney Company | reports | Consumer Discretionary | Broadcasting & Cable TV | Burbank, California | 1976-06-30 | 0001001039
WM | Waste Management Inc. | reports | Industrials | Environmental Services | Houston, Texas |  | 0000823768
WAT | Waters Corporation | reports | Health Care | Health Care Distributors & Services | Milford, Massachusetts |  | 0001000697
WFC | Wells Fargo | reports | Financials | Banks | San Francisco, California | 1976-06-30 | 0000072971
HCN | Welltower Inc. | reports | Real Estate | REITs | Toledo, Ohio | 2009-01-30 | 0000766704
WDC | Western Digital | reports | Information Technology | Computer Storage & Peripherals | Irvine, California | 2009-07-01 | 0000106040
WU | Western Union Co | reports | Information Technology | Internet Software & Services | Englewood, Colorado |  | 0001365135
WRK | Westrock Co | reports | Materials | Paper Packaging | Richmond, Virginia |  | 0001636023
WY | Weyerhaeuser Corp. | reports | Real Estate | REITs | Federal Way, Washington |  | 0000106535
WHR | Whirlpool Corp. | reports | Consumer Discretionary | Household Appliances | Benton Harbor, Michigan |  | 0000106640
WFM | Whole Foods Market | reports | Consumer Staples | Food Retail | Austin, Texas |  | 0000865436
WMB | Williams Cos. | reports | Energy | Oil & Gas Exploration & Production | Tulsa, Oklahoma | 1975-03-31 | 0000107263
WLTW | Willis Towers Watson | reports | Financials | Insurance Brokers | London, United Kingdom | 2016-01-05 | 0001140536
WEC | Wisconsin Energy Corporation | reports | Utilities | Electric Utilities | Milwaukee, Wisconsin | 2008-10-31 | 0000783325
WYN | Wyndham Worldwide | reports | Consumer Discretionary | Hotels, Resorts & Cruise Lines | Parsippany, New Jersey |  | 0001361658
WYNN | Wynn Resorts Ltd | reports | Consumer Discretionary | Casinos & Gaming | Las Vegas, Nevada | 2008-11-14 | 0001174922
XEL | Xcel Energy Inc | reports | Utilities | MultiUtilities | Minneapolis, Minnesota |  | 0000072903
XRX | Xerox Corp. | reports | Information Technology | IT Consulting & Services | Norwalk, Connecticut |  | 0000108772
XLNX | Xilinx Inc | reports | Information Technology | Semiconductors | San Jose, California |  | 0000743988
XL | XL Capital | reports | Financials | Property & Casualty Insurance | Hamilton, Bermuda |  | 0000875159
XYL | Xylem Inc. | reports | Industrials | Industrial Conglomerates | White Plains, New York | 2011-11-01 | 0001524472
YHOO | Yahoo Inc. | reports | Information Technology | Internet Software & Services | Sunnyvale, California |  | 0001011006
YUM | Yum! Brands Inc | reports | Consumer Discretionary | Restaurants | Louisville, Kentucky | 1997-10-06 | 0001041061
ZBH | Zimmer Biomet Holdings | reports | Health Care | Health Care Equipment & Services | Warsaw, Indiana |  | 0001136869
ZION | Zions Bancorp | reports | Financials | Banks | Salt Lake City, Utah |  | 0000109380
ZTS | Zoetis | reports | Health Care | Pharmaceuticals | Florham Park, New Jersey | 2013-06-21 | 0001555280

## Recent and announced changes to the list of S&P 500 Components[edit]

S&P Dow Jones Indices updates the components of the S&P 500 periodically, typically in response to acquisitions, or to keep the index up to date as various companies grow or shrink in value.[7] Between January 1, 1963 and December 31, 2014, 1,186 index components were replaced by other components.[8]

| Added | Removed
Date | Ticker | Security | Ticker | Security | Reason
September 30, 2016 | COTY | Coty, Inc | DO | Diamond Offshore Drilling Inc | COTY replaces DO[9]
September 22, 2016 | COO | The Cooper Companies | HOT | Starwood Hotels & Resorts Worldwide Inc | MAR acquires HOT[10]
September 8, 2016 | CHTR | Charter Communications | EMC | EMC Corporation | Dell acquires EMC[11]
September 6, 2016 | MTD | Mettler Toledo | JCI | Johnson Controls Inc | TYC acquires JCI (and becomes new JCI)[12]
July 5, 2016 | FTV | Fortive Corp | CPGX | Columbia Pipeline Group Inc | CPGX acquired by TRP[13]
July 1, 2016 | LNT | Alliant Energy Corp | GAS | AGL Resources | GAS acquired by SO[14]
July 1, 2016 | ALB | Albemarle Corp | TE | TECO Energy | TE acquired by EMA[15]
June 22, 2016 | FBHS | Fortune Brands Home & Security | CVC | Cablevision Systems | CVC acquired by Altice NV[16]
June 3, 2016 | TDG | TransDigm Group | BXLT | Baxalta Inc | SHPG acquiring BXLT[17]
May 31, 2016 | AJG | Arthur J. Gallagher & Co. | CCE | Coca-Cola Enterprises | CCE merging with European bottlers[18]
May 23, 2016 | LKQ | LKQ Corporation | ARG | Airgas Inc | ARG acquired by Air Liquide[19]
May 18, 2016 | DLR | Digital Realty Trust | TWC | Time Warner Cable | TWC acquired by CHTR[20]
May 13, 2016 | ALK | Alaska Air Group Inc | SNDK | SanDisk Corporation | SNDK acquired by WDC[21]
May 3, 2016 | AYI | Acuity Brands Inc | ADT | ADT Corp | ADT acquired by APO [22]
April 27, 2016 | SPGI | S&P Global, Inc. | MHFI | McGraw Hill Financial, Inc. | McGraw Hill Financial, Inc. rebrands as S&P Global, Inc. [23]
April 25, 2016 | GPN | Global Payments | GME | GameStop | Global Payments is acquiring Heartland Payment Systems [24]
April 18, 2016 | ULTA | Ulta Salon, Cosmetics & Fragrance Inc | THC | Tenet Healthcare | Ulta replaces Tenet[25]
April 4, 2016 | FL | Foot Locker Inc | CAM | Cameron International | Schlumberger acquired Cameron[26]
March 30, 2016 | HOLX | Hologic Inc | POM | Pepco Holdings Inc | Exelon Corp acquired Pepco[27]
March 30, 2016 | CNC | Centene Corporation | ESV | Ensco plc | Centene acquired Health Net[27]
March 7, 2016 | UDR | UDR Inc | GMCR | Keurig Green Mountain | JAB Holding Company acquired Keurig Green Mountain[28]
March 4, 2016 | AWK | American Water Works Company Inc | CNX | Consol Energy | AWK replaces CNX[29]
February 22, 2016 | CXO | Concho Resources | PCL | Plum Creek Timber | PCL taken over by WY[30]
February 1, 2016 | CFG | Citizens Financial Group | PCP | Precision Castparts Corp. | CFG replaces PCP[31]
February 1, 2016 | FRT | Federal Realty Investment Trust | BRCM | Broadcom Corporation | FRT replaces BRCM[32]
January 19, 2016 | EXR | Extra Space Storage | CB | Chubb Corp | EXR replaces CB[33]
January 5, 2016 | WLTW | Willis Towers Watson | FOSL | Fossil Group | WSH merges with TW (and renames to WLTW)[34]
December 29, 2015 | CHD | Church & Dwight | ALTR | Altera Corp | ALTR taken over by INTC[35]
December 15, 2015 |  |  | CMCSK | Comcast K Corp | CMCSK shares no longer listed[36]
December 1, 2015 | CSRA | CSRA Inc | CSC | Computer Sciences Corp | CSC spins off CSRA[37]
November 19, 2015 | ILMN | Illumina Inc | SIAL | Sigma-Aldrich Corp | Sigma-Aldrich acquired by Merck KGaA (MKGAY)[38]
November 18, 2015 | SYF | Synchrony Financial | GNW | Genworth Financial | GE spinning off Synchrony Financial[39]
November 2, 2015 | HPE | Hewlett Packard Enterprise | HCBK | Hudson City Bancorp Inc | HPQ spins off HPE[40]
October 7, 2015 | VRSK | Verisk Analytics | JOY | Joy Global | Market capitalization change.[41]
September 18, 2015 | CMCSK | Comcast Class K Special |  |  | Share class methodology change[42]
FOX | Twenty-First Century Fox Class B |  |
NWS | News Corporation Class B |  |
September 2, 2015 | UAL | United Continental Holdings | HSP | Hospira Inc | Hospira taken over[43]
August 28, 2015 | ATVI | Activision Blizzard | PLL | Pall Corp | Pall taken over[44]
July 29, 2015 | SIG | Signet Jewelers | DTV | DirecTV | DirectTV acquired by AT&T[45]
July 20, 2015 | PYPL | PayPal | NE | Noble Corp | PayPal Spun off by eBay[46]
July 8, 2015 | AAP | Advance Auto Parts | FDO | Family Dollar Stores Inc. | Family Dollar Acquired.[47]
July 2, 2015 | CPGX | Columbia Pipeline Group Inc. | ATI | Allegheny Technologies | Spin off of Columbia Pipeline.[48]
July 1, 2015 | JBHT | J. B. Hunt | TEG | Integrys Energy Group Inc. | Integris taken over.[49]
July 1, 2015 | BXLT | Baxalta | QEP | QEP Resources | Baxalta spun off by Baxter.[50]
June 11, 2015 | QRVO | Qorvo | LO | Lorillard Inc. | Lorillard Inc. gets acquired.[51]
April 7, 2015 | O | Realty Income Corporation | WIN | Windstream Holdings Inc | Market capitalization change.[52]
March 23, 2015 | AAL | American Airlines Group | AGN | Allergan, Inc | Allergan acquired by Actavis plc (and changed name to Allergan, pl.[53]
March 23, 2015 | EQIX | Equinix | DNR | Denbury Resources | Market Capitalization Changes.[54]
SLG | SL Green Realty | NBR | Nabors Industries
HBI | Hanesbrands | AVP | Avon Products
March 18, 2015 | HSIC | Henry Schein | CFN | Carefusion | Carefusion acquired by Becton Dickinson[55]
March 12, 2015 | SWKS | Skyworks Solutions Inc. | PETM | PetSmart Inc. | PetSmart acquired by private equity consortium[56]
January 27, 2015 | HCA | HCA Holdings | SWY | Safeway Inc | Safeway acquired by private equity consortium[57]
January 27, 2015 | ENDP | Endo International | COV | Covidien | Covidien acquired by Medtronic[58]
December 5, 2014 | RCL | Royal Caribbean Cruises Ltd | BMS | Bemis Company | Market cap changes[59]
November 5, 2014 | LVLT | Level 3 Communications | JBL | Jabil Circuit | Market cap changes[60]
September 20, 2014 | URI | United Rentals | BTU | Peabody Energy | Market cap changes[61]
UHS | Universal Health Services | GHC | Graham Holdings
August 18, 2014 | MNK | Mallinckrodt Plc | RDC | Rowan Companies Plc | Market cap changes[62]
August 6, 2014 | DISCK | Discovery Communications |  |  | Class C share distribution[63]
July 2, 2014 | MLM | Martin Marietta Materials | X | United States Steel Corporation | Market capitalization changes[64]
July 1, 2014 | AMG | Affiliated Managers Group Inc | FRX | Forest Laboratories | Actavis acquires Forrest Laboratories[65]
June 20, 2014 | XEC | Cimarex Energy | IGT | International Game Technology | Market capitalization changes[66]
May 8, 2014 | AVGO | Avago Technologies | LSI | LSI Corporation | Avago acquires LSI[67]
May 1, 2014 | UA | Under Armour | BEAM | Beam Inc. | Beam acquired by Suntory[68]
May 1, 2014 | NAVI | Navient | SLM | SLM Corporation | Navient Spun off from SLM[68]
April 3, 2014 | GOOGL | Google Inc. |  |  | Google Class C share distribution[69]
April 2, 2014 | ESS | Essex Property Trust Inc | CLF | Cliffs Natural Resources | Market capitalization changes[70]
March 21, 2014 | GMCR | Keurig Green Mountain | WPX | WPX Energy, Inc. | Market capitalization changes[71]
January 24, 2014 | TSCO | Tractor Supply Company | LIFE | Life Technologies | Life Technologies acquired by Thermo Fisher Scientific Inc[72]
December 21, 2013 | ADS | Alliance Data Systems | ANF | Abercrombie & Fitch | Market capitalization changes[73]
MHK | Mohawk Industries | JDSU | JDS Uniphase
FB | Facebook | TER | Teradyne
December 10, 2013 | GGP | General Growth Properties Inc. | MOLX | Molex Inc. | MOLX acquired by Koch Industries[74]
December 2, 2013 | ALLE | Allegion | JCP | J.C. Penney | Allegion spun off by Ingersoll Rand[75]
November 13, 2013 | KORS | Michael Kors | NYX | NYSE Euronext | ICE Exchange acquired NYSE Euronext[76]
October 21, 2013 | RIG | Transocean | DELL | Dell, Inc. | Dell acquired by private equity consortium[77]
September 20, 2013 | VRTX | Vertex Pharmaceuticals | AMD | Advanced Micro Devices | Market capitalization changes[78]
AME | Ametek | SAIC | SAIC
September 10, 2013 | DAL | Delta Air Lines | BMC | BMC Software | BMC taken private by consortium[79]
July 8, 2013 | NLSN | Nielsen Holdings | S | Sprint Nextel Corp. | Softbank consortium purchase results in public float below 50%[80]
June 28, 2013 | FOXA | 21st Century Fox | APOL | Apollo Group Inc. | Apollo Group's market cap more representative of a mid-cap[81]
June 21, 2013 | ZTS | Zoetis | FHN | First Horizon | Zoetis spun off by Pfizer[82]
June 6, 2013 | GM | General Motors | HNZ | H. J. Heinz Company | HNZ acquired by consortium[83]
May 23, 2013 | KSU | Kansas City Southern | DF | Dean Foods | DF too small after spinoff of White Wave Foods[84]
May 8, 2013 | MAC | Macerich | CVH | Coventry Health Care | Acquired by Aetna (AET)[85]
April 30, 2013 | REGN | Regeneron | PCS | MetroPCS | A majority of MetroPCS was acquired by T-Mobile[86]
February 15, 2013 | PVH | PVH Corp. | BIG | Big Lots Inc. | Market capitalization changes[87]
December 31, 2012 | ABBV | AbbVie | FII | Federated Investors | ABBV spun off from Abbott Labs (ABT)[88]
December 21, 2012 | DLPH | Delphi Automotive | TIE | Titanium Metals | TIE acquired by Precision Cast Parts (PCP)[89]
December 11, 2012 | GRMN | Garmin Ltd. | RRD | R.R. Donnelley | Market capitalization changes[90]
December 3, 2012 | DG | Dollar General | CBE | Cooper Industries | Acquired by Eaton Corp. (ETN)[91]
October 10, 2012 | PETM | PetSmart, Inc. | SUN | Sunoco Inc. | Acquired by Energy Transfer Partners (ETP)[92]
October 2, 2012 | KRFT | Kraft Foods Group | ANR | Alpha Natural Resources | Kraft split into two companies[93]
October 1, 2012 | ADT | ADT Corp | LXK | Lexmark Int'l Inc | Tyco spun off ADT[94]
October 1, 2012 | PNR | Pentair Ltd. | DV | DeVry, Inc. | Tyco spin-off merged w/Pentair[94]
September 5, 2012 | LYB | LyondellBasell | SHLD | Sears Holding Corporation | SHLD below public float threshold[95]
July 31, 2012 | ESV | Ensco plc | GR | Goodrich Corporation | Acquired by United Technologies (UTX)[96]
July 2, 2012 | STX | Seagate Technology | PGN | Progress Energy Inc | Acquired by Duke Energy (DUK)[97]
June 29, 2012 | MNST | Monster Beverage | SLE | Sara Lee Corp. | Split up of Sara Lee[98]
June 5, 2012 | LRCX | Lam Research | NVLS | Novellus Systems | Acquired by Lam Research (LRCX)[99]
May 21, 2012 | ALXN | Alexion Pharmaceuticals | MMI | Motorola Mobility | Acquired by Google (GOOG)[100]
May 17, 2012 | KMI | Kinder Morgan | EP | El Paso Corp. | Acquired by Kinder Morgan (KMI)[101]
April 23, 2012 | PSX | Phillips 66 | SVU | Supervalu Inc. | ConocoPhillips spun off Phillips 66[102]
April 3, 2012 | FOSL | Fossil, Inc. | MHS | Medco Health Solutions Inc. | Acquired by Express Scripts (ESRX)[103]
March 13, 2012 | CCI | Crown Castle International Corp. | CEG | Constellation Energy Group | Acquired by Exelon Corp. (EXC)[104]
December 31, 2011 | WPX | WPX Energy, Inc. | CPWR | Compuware | Market capitalization changes[105]
December 20, 2011 | TRIP | TripAdvisor Inc. | TLAB | Tellabs Inc. | Expedia Inc. spun off TripAdvisor Inc.[106]
December 16, 2011 | BWA | BorgWarner Inc. | AKS | AK Steel Holding Corp. | Market capitalization changes[107]
PRGO | Perrigo Co. | MWW | Monster Worldwide Inc.
DLTR | Dollar Tree Inc. | WFR | MEMC Electronic Materials Inc.
December 12, 2011 | GAS | AGL Resources Inc. | GAS | Nicor Inc. | Nicor acquired by AGL, which retained the GAS ticker.[108]
November 18, 2011 | CBE | Cooper Industries | JNS | Janus Capital Group | Janus Capital Group’s market capitalization is less than $1.2 billion and is no longer representative of the large cap market space.[109]
October 31, 2011 | XYL | Xylem Inc. | ITT | ITT Corp. | Spun off from ITT Corp.[110]
October 14, 2011 | TEL | TE Connectivity Ltd. | CEPH | Cephalon Inc. | Acquired by Teva Pharmaceutical Industries (TEVA).[111]
September 23, 2011 | MOS | The Mosaic Company | NSM | National Semiconductor Corp. | Acquired by Texas Instruments (TXN).[112]
July 5, 2011 | ACN | Accenture plc | MI | Marshall & Iisley Corp. | Marshall & Iisley is being bought by Bank of Montreal[113]
June 30, 2011 | MPC | Marathon Petroleum Corp | RSH | RadioShack Corp. | Market capitalization adjustments.[114]
June 1, 2011 | ANR | Alpha Natural Resources, Inc. | MEE | Massey Energy Company | Alpha Natural Resources is acquiring Massey Energy in a deal expected to be completed on or about that date pending final approvals.[115]
April 27, 2011 | CMG | Chipotle | NOVL | Novell, Inc. | Acquired by private equity firms.[116]
April 1, 2011 | BLK | BlackRock | GENZ | Genzyme Corp. | Acquired by Sanofi-aventis (SNY)[117]
March 31, 2011 | EW | Edwards Lifesciences | Q | Qwest Communications | Acquired by CenturyLink[118]
February 28, 2011 | COV | Covidien Plc | MFE | McAfee Inc. | Acquired by Intel Corp. (INTC)[119]
February 25, 2011 | JOY | Joy Global Inc. | AYE | Allegheny Energy Inc. | Acquired by First Energy (FE).[120]
December 17, 2010 | CVC | Cablevision Systems Corp. | KG | King Pharmaceuticals Inc. | Acquired by Pfizer Inc. (PFE)[121]
December 17, 2010 | FFIV | F5 Networks Inc. | EK | Eastman Kodak Co. | Market Cap changes.[122]
NFLX | Netflix Inc. | ODP | Office Depot Inc.
NFX | Newfield Exploration Co. | NYT | The New York Times Co.
August 26, 2010 | TYC | Tyco International Ltd. | SII | Smith International Inc. | Acquired by Schlumberger Ltd. (SLB)[123]
July 14, 2010 | ACE | Ace Limited | MIL | Millipore Inc. | Acquired by Merck KGaA (MKGAY)[124]
June 30, 2010 | QEP | QEP Resources | STR | Questar Corp. | Company split. QEP retained, but ticker changed.[125]
June 28, 2010 | KMX | CarMax, Inc. | XTO | XTO Energy Inc. | Acquired by ExxonMobil Inc. (XOM)[126]
April 29, 2010 | CERN | Cerner Corp. | BJS | BJ Services Company | Acquired by Baker Hughes Inc. (BHI)[127]
February 26, 2010 | HP | Helmerich & Payne | RX | IMS Health | Taken private[128]
November 3, 2009 | PCLN | Priceline.com | SGP | Schering-Plough Corp. | Acquired by Merck & Co. (MRK)[129]
September 28, 2009 | ARG | Airgas Inc | CBE | Cooper Industries Ltd. | Redomesticated to Ireland[130]
June 10, 2008 | LO | Lorillard Inc. | ABK | Ambac Financial | Market Value Decline[131]
December 20, 2007 | RRC | Range Resources | TRB | Tribune Co. | Taken private[132]
October 25, 2007 | JEC | Jacobs Engineering Group | AV | Avaya Inc. | Taken private[133]
January 10, 2007 | AVB | AvalonBay Communities, Inc. | SBL | Symbol Technologies | Acquired by Motorola[134]
September 25, 2003 | ESRX | Express Scripts | QTRN | Quintiles Transnational | Taken private[135]
December 5, 2000 | INTU | Intuit | BS | Bethlehem Steel | Market Cap changes.[136]
SBL | Symbol Technologies | OI | Owens-Illinois
AYE | Allegheny Energy | GRA | W.R. Grace
ABK | Ambac Financial | CCK | Crown Holdings

## See also[edit]

- Dow Jones Industrial Average#Components
- NASDAQ-100#Components
- List of S&P 400 companies

## External links[edit]

- Standard & Poor's page on S&P 500 index
- Current S&P 500 components, market caps and outstanding shares
- Historical S&P 500 components

## References[edit]

1. ^ "The S&P 500 is becoming the S&P 502 .". USA Today. 2014-07-30. Retrieved 2014-12-02.
2. ^ "S&P U.S. Indices Methodology Update" (PDF). www.spice-indices.com. 2015-01-12. Retrieved 2015-03-13.
3. ^ "Our Company". AvalonBay. 1994-12-31. Retrieved 2012-02-10.
4. ^ http://www.bostonscientific.com/en-US/about-us/new-marlborough-headquarters.html
5. ^ "Helmerich & Payne, Inc". Hpinc.com. Retrieved 2012-02-10.
6. ^ "Offices | Southwestern Energy". Swn.com. Retrieved 2012-02-10.
7. ^ "S&P 500 Changes". sandp500changes.whw1.com. Retrieved 2015-03-10.
8. ^ sibilisresearch.com "S&P 500 Historical Components & Composition Change", 25 March 2015.
9. ^ "Coty Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-09-27. Retrieved 2016-09-27.
10. ^ "The Cooper Companies Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-09-10. Retrieved 2016-09-20.
11. ^ "Charter Communications to Join S&P 500" (PDF). www.spice-indices.com. 2016-08-31. Retrieved 2016-08-31.
12. ^ "Mettler-Toledo International Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-08-25. Retrieved 2016-08-25.
13. ^ "Albemarle and Fortive Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-06-23. Retrieved 2016-06-23.
14. ^ "Alliant Energy Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-06-29. Retrieved 2016-06-29.
15. ^ "Albemarle and Fortive Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-06-23. Retrieved 2016-06-23.
16. ^ "Fortune Brands Home & Security Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-06-21. Retrieved 2016-06-21.
17. ^ "TransDigm Group Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-05-27. Retrieved 2016-05-27.
18. ^ "Arthur J. Gallagher & Co. Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-05-24. Retrieved 2016-05-24.
19. ^ "LKQ Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-05-18. Retrieved 2016-05-18.
20. ^ "Digital Realty Trust Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-05-13. Retrieved 2016-05-13.
21. ^ "Alaska Air Group Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-05-10. Retrieved 2016-05-10.
22. ^ "Acuity Brands Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-04-26. Retrieved 2016-04-26.
23. ^ "McGraw Hill Financial Changes Name to S&P Global". www.mhfi.com. 2016-04-27. Retrieved 2016-05-03.
24. ^ "Global Payments Set to Join the S&P 500" (PDF). www.spice-indices.com. 2017-04-19. Retrieved 2016-04-19.
25. ^ "Ulta Salon, Cosmetics & Fragrance Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-04-07. Retrieved 2016-04-07.
26. ^ "Foot Locker Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-03-28. Retrieved 2016-03-28.
27. ^ a b "Hologic, Centene Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-03-24. Retrieved 2016-03-24.
28. ^ "UDR Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-03-04. Retrieved 2016-03-04.
29. ^ "American Water Works Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-03-01. Retrieved 2016-03-01.
30. ^ "Concho Resources Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-02-16. Retrieved 2016-02-16.
31. ^ "Citizens Financial Group Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-01-26. Retrieved 2016-01-26.
32. ^ "Federal Realty Investment Trust Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-01-22. Retrieved 2016-01-22.
33. ^ "Extra Space Storage Set to Join the S&P 500" (PDF). www.spice-indices.com. 2016-01-15. Retrieved 2016-01-13.
34. ^ "Willis Group Holdings Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-12-28. Retrieved 2015-12-28.
35. ^ "Church & Dwight Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-12-22. Retrieved 2015-12-22.
36. ^ "CMCSK SEC filing". www.spice-indices.com. 2015-12-15. Retrieved 2015-12-15.
37. ^ "CSRA to Join the S&P 500" (PDF). www.spice-indices.com. 2015-11-23. Retrieved 2015-11-23.
38. ^ "Illumina Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-11-12. Retrieved 2015-11-12.
39. ^ "Synchrony Financial Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-11-09. Retrieved 2015-11-09.
40. ^ "Hewlett Packard Enterprise to Join the S&P 500" (PDF). www.spice-indices.com. 2015-10-27. Retrieved 2015-10-27.
41. ^ "Verisk Analytics Set to Join the S&P 500; Joy Global to Join S&P Mid Cap 400" (PDF). www.spice-indices.com. 2015-09-30. Retrieved 2015-09-30.
42. ^ "S&P U.S. Indices Methodology Update" (PDF). www.spice-indices.com. 2015-01-12. Retrieved 2015-03-13.
43. ^ "Activision Blizzard, United Continental Holdings Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-08-27. Retrieved 2015-08-27.
44. ^ "Activision Blizzard, United Continental Holdings Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-08-27. Retrieved 2015-08-27.
45. ^ "Signet Jewelers Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-07-24. Retrieved 2015-07-24.
46. ^ "PayPal Holdings Set to Join S&P 100 & 500" (PDF). www.spice-indices.com. 2015-07-14. Retrieved 2015-07-14.
47. ^ "Advance Auto Parts Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-07-06. Retrieved 2015-10-10.
48. ^ "Columbia Pipeline to Join the S&P 500" (PDF). www.spice-indices.com. 2015-06-23. Retrieved 2015-06-23.
49. ^ "J.B. Hunt Transport Services Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-06-29. Retrieved 2015-06-29.
50. ^ "Baxalta to Join the S&P 500" (PDF). www.spice-indices.com. 2015-06-19. Retrieved 2015-06-19.
51. ^ "Qorvo Set to Join the S&P 500." (PDF). spice-indices.com. 2015-06-09. Retrieved 2015-06-10.
52. ^ "Realty Income Set to Join S&P 500" (PDF). spice-indices.com. 2015-03-30. Retrieved 2015-03-30.
53. ^ "American Airlines Group Set to Join the S&P 500" (PDF). spice-indices.com. 2015-03-16. Retrieved 2015-03-17.
54. ^ "Celgene, Kinder Morgan and Actavis . . ." (PDF). www.spice-indices.com. 2015-03-13. Retrieved 2015-03-13.
55. ^ "Celgene, Kinder Morgan and Actavis . . ." (PDF). www.spice-indices.com. 2015-03-13. Retrieved 2015-03-13.
56. ^ "Skyworks Solutions Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-03-09. Retrieved 2015-03-10.
57. ^ "HCA Holdings Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-01-23. Retrieved 2015-01-26.
58. ^ "Endo International Set to Join the S&P 500" (PDF). www.spice-indices.com. 2015-01-21. Retrieved 2015-01-26.
59. ^ "Royal Caribbean Cruises Set to Join the S&P 500" (PDF). www.spice-indices.com. 2014-12-01. Retrieved 2014-12-01.
60. ^ "Level 3 Communications Set to Join the S&P 500; Jabil Circuit to Join the S&P MidCap 400" (PDF). www.spice-indices.com. 2014-10-29. Retrieved 2014-10-29.
61. ^ "United Rentals and Universal Health Services to Join the S&P 500; Changes to the S&P MidCap 400 and the S&P SmallCap 600" (PDF). www.spice-indices.com. 2014-09-12. Retrieved 2014-09-27.
62. ^ "Mallinckrodt Set to Join the S&P 500" (PDF). www.spice-indices.com. 2014-08-14. Retrieved 2014-08-19.
63. ^ "S&P Dow Jones Indices Announces Treatment of Stock Dividend for Discovery Communications in S&P 500" (PDF). www.spice-indices.com. 2014-07-30. Retrieved 2014-08-08.
64. ^ "Martin Marietta Materials Set to Join the S&P 500" (PDF). www.spice-indices.com. 2014-06-27. Retrieved 2014-06-27.
65. ^ "Affiliated Managers Group Set to Join S&P 500" (PDF). www.spice-indices.com. 2014-06-24. Retrieved 2014-06-24.
66. ^ "Cimarex Energy to Join the S&P 500" (PDF). www.spice-indices.com. 2014-06-12. Retrieved 2014-06-12.
67. ^ "Avago Technologies Set to Join the S&P 500". www.bloomberg.com. 2014-05-05. Retrieved 2014-05-05.
68. ^ a b "Navient, Under Armour Set to Join the S&P 500" (PDF). www.spice-indices.com. 2014-04-24. Retrieved 2014-04-24.
69. ^ "S&P Dow Jones Indices Announces Changes in Treatment of Multiple Share Classes" (PDF). www.spice-indices.com. 2014-04-02. Retrieved 2014-03-11.
70. ^ "Essex Property Set to Join S&P 500". bloomberg.com. 2014-04-02. Retrieved 2014-04-02.
71. ^ Ciolli, Joseph (2014-03-14). "Keurig Green Mountain to Replace WPX Energy in S&P 500 Index". bloomberg.com. Retrieved 2014-03-21.
72. ^ "Tractor Supply Set to Join the S&P 500". bloomberg.com. 2014-01-16. Retrieved 2014-01-31.
73. ^ "Facebook Set to Join the S&P 100 & 500; Alliance Data Systems and Mohawk to Join the S&P 500; Changes to the S&P MidCap 400 and the S&P SmallCap 600" (PDF). us.spindices.com. 2013-12-11. Retrieved 2013-12-20.
74. ^ "General Growth Properties Set to Join the S&P 500". bloomberg.com. 2013-12-04. Retrieved 2013-12-04.
75. ^ Taborek, Nick (2013-11-22). "J.C. Penney Will Be Replaced by Allegion in S&P 500 After Drop". bloomberg.com. Retrieved 2013-12-01.
76. ^ "ICE Closes on $11B Acquisition of NYSE Euronext; ...". AP. 2013-11-13. Retrieved 2013-11-13.
77. ^ "Transocean Set to Join the S&P 500; ...". WSJ. 2013-10-21. Retrieved 2013-12-03. [dead link]
78. ^ "Vertex, Ametek Set to Join the S&P 500; ..." (PDF). S&P Dow Jones Indices. Retrieved 2013-09-11.
79. ^ "Delta Air Lines Set to Join the S&P 500; ..." (PDF). S&P Dow Jones Indices. 2013-09-10. Retrieved 2013-09-10.
80. ^ "Nielsen Set to Join the S&P 500; ..." (PDF). S&P Dow Jones Indices. 2013-07-01. Retrieved 2013-07-08.
81. ^ "News Corp. Set to Join S&P 500; Mallinckrodt, Apollo to Join S&P MidCap 400; Forest Oil, Tesco to Join S&P SmallCap 600; ..." (PDF). S&P Dow Jones Indices. 2013-06-20. Retrieved 2013-07-08.
82. ^ "Zoetis Set to Join S&P 500; First Horizon National to Join S&P MidCap 400; ..." (PDF). S&P Dow Jones Indices. 2013-06-14. Retrieved 2013-08-23.
83. ^ "General Motors Set to Join S&P 100 & 500; ..." (PDF). S&P Dow Jones Indices. 2013-06-03. Retrieved 2013-06-07.
84. ^ "Kansas City Southern set to join S&P 500; ..." (PDF). S&P Dow Jones Indices. Retrieved 14 June 2013.
85. ^ "Macerich Set to Join the S&P 500; ...". www.standardandpoors.com. 2013-05-03. Retrieved 2013-05-09.
86. ^ "Regeneron Set to Join S&P 500; ...". www.standardandpoors.com. 2013-04-24. Retrieved 2013-04-24.
87. ^ "PVH Set to Join S&P 500; ...". www.standardandpoors.com. 2013-02-07. Retrieved 2013-02-16.
88. ^ "AbbVie Set to Join S&P 100 & 500; ...". standardandpoors.com. 2012-12-20. Retrieved 2012-12-26.
89. ^ "Delphi Automotive Set to Join S&P 500". standardandpoors.com. 2012-12-18. Retrieved 2012-12-26.
90. ^ "Garmin Set to Join the S&P 500; ...". standardandpoors.com. 2012-12-05. Retrieved 2012-12-17.
91. ^ "Dollar General Set to Join the S&P 500". standardandpoors.com. 2012-11-26. Retrieved 2012-12-05.
92. ^ "PetSmart Set to Join the S&P 500; ...". standardandpoors.com. 2012-10-01. Retrieved 2012-10-10.
93. ^ "Kraft Foods Group Set to Join the S&P 500; ...". standardandpoors.com. 2012-09-25. Retrieved 2012-10-02.
94. ^ a b "ADT, Pentair Set to Join the S&P 500; ...". standardandpoors.com. 2012-09-24. Retrieved 2012-10-02.
95. ^ "LyondellBasell Industries Set to Join the S&P 500". standardandpoors.com. 2012-08-29. Retrieved 2012-09-05.
96. ^ "Ensco plc Set to Join the S&P 500". standardandpoors.com. 2012-07-26. Retrieved 2012-08-01.
97. ^ "S&P Indices Announces Change to U.S. Index" (PDF). spindices.com. 2012-06-25. Retrieved 2012-07-03.
98. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). spindices.com. 2012-06-21. Retrieved 2012-06-30.
99. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). spindices.com. 2012-05-10. Retrieved 2012-06-06.
100. ^ "S&P Indices Announces Change to U.S. Index". standardandpoors.com. 2012-05-21. Retrieved 2012-05-29.
101. ^ "S&P Indices Announces Change to U.S. Index". standardandpoors.com. 2012-05-17. Retrieved 2012-05-29.
102. ^ "S&P Indices Announces Changes to U.S. Indices". standardandpoors.com. 2012-04-23. Retrieved 2012-05-03.
103. ^ "Medco Health Solutions, Inc. (MHS) in the S&P 500". standardandpoors.com. 2012-04-02. Retrieved 2012-04-06.
104. ^ "Constellation Energy Group (CEG) in the S&P 500". standardandpoors.com. 2012-03-12. Retrieved 2012-04-06.
105. ^ "MarketWatch.com". MarketWatch.com. 2011-12-11. Retrieved 2012-02-10.
106. ^ "S&P | S&P Indices Announces Changes to U.S. Indices | Americas". Standardandpoors.com. Retrieved 2012-02-10.
107. ^ "S&P | S&P Indices Announces Changes to U.S. Indices | Americas". Standardandpoors.com. Retrieved 2012-02-10.
108. ^ "S&P adds AGL Resources to S&P 500". BusinessWeek. 2011-12-08. Retrieved 2012-02-10.
109. ^ "S&P | S&P Indices Announces Changes to U.S. Indices | Americas". Standardandpoors.com. Retrieved 2012-07-25.
110. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). Standard & Poors. 24 October 2011. Retrieved 2013-10-25.
111. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). Standard & Poors. 11 October 2011. Retrieved 2013-10-25.
112. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). Standard & Poors. 21 September 2011. Retrieved 2013-10-25.
113. ^ "S&P Indices Announces Changes to U.S. Indices" (PDF). Standard & Poors. 27 June 2011. Retrieved 2013-10-25.
114. ^ "S&P | Standard & Poor's Announces Changes to U.S. Indices | Americas". Standardandpoors.com. Retrieved 2012-02-10.
115. ^ Quotes delayed at least 15 min (1999-12-31). "Business news: Financial, stock & investing news online – MSN Money". Money.msn.com. Retrieved 2012-07-25.
116. ^ "S&P | Novell Inc. (NOVL) in the S&P 500 | Americas". Standardandpoors.com. Retrieved 2012-06-06.
117. ^ BlackRock to join S&P 500 index, replacing Genzyme
118. ^ "Cooper Graduates To Midcap Status, Edwards Replace Qwest In S&P 500". Forbes. March 25, 2011.
119. ^ "S&P | McAfee Inc. (MFE) in the S&P 500 | Americas". Standardandpoors.com. Retrieved 2012-07-25.
120. ^ "S&P | Allegheny Energy Inc. (AYE) in the S&P 500 | Americas". Standardandpoors.com. Retrieved 2012-07-25.
121. ^ S&P 500 Announces Changes to Stock Lineup
122. ^ Sign of the Times: Netflix Added, New York Times Dropped From S&P 500
123. ^ "Tyco International to replace Smith on S&P 500". MarketWatch. Retrieved 2012-07-25.
124. ^ "Reinsurer Ace to replace Millipore in S&P 500". MarketWatch. Retrieved 2012-07-25.
125. ^ "QEP Resources to replace Questar on S&P 500". MarketWatch. Retrieved 2012-07-25.
126. ^ "CarMax replacing XTO Energy on the S&P 500". MarketWatch. Retrieved 2012-07-25.
127. ^ "S&P | BJ Services (BJS) in the S&P 500 | Americas". Standardandpoors.com. Retrieved 2012-07-25.
128. ^ "Standard & Poor's Announces Changes To U.S. Indices". PRNewsWire.com. 2010-02-22. Retrieved 2016-11-01.
129. ^ "S&P 500 Stocks » PLN – Priceline.com Inc. Replaces SGP – Schering-Plough In S&P 500 Index". S-p-500.com. 2009-11-03. Retrieved 2012-07-25.
130. ^ The Associated Press (2009-08-31). "Airgas Replaces Cooper Industries On S&P 500". TheStreet. Retrieved 2013-10-25.
131. ^ Bloomberg (2008-06-03). "Lorrollard to Replace Ambac Financial". Bloomberg. Retrieved 2013-12-28.
132. ^ "MarketWatch.com". MarketWatch.com. 2011-10-18. Retrieved 2013-10-25.
133. ^ "Marketwatch.com". Marketwatch.com. 2007-10-23. Retrieved 2015-03-06.
134. ^ "MarketWatch.com". MarketWatch.com. 2007-01-04. Retrieved 2013-12-28.
135. ^ "Standard & Poor's Announces Changes To S&P U.S. Indices". PRNewsWire.com. 2003-09-23. Retrieved 2016-11-01.
136. ^ Published: December 05, 2000 (2000-12-05). "S.& P. Eliminates 4 Old-Line Stocks From Its 500 Index – New York Times". Nytimes.com. Retrieved 2013-10-25.

Retrieved from "https://en.wikipedia.org/w/index.php?title=List_of_S%26P_500_companies&oldid=748003310"
Categories:

- S&P Dow Jones Indices
- Lists of companies
- Standard & Poor's

Hidden categories:

- All articles with dead external links
- Articles with dead external links from August 2015